@@ -4,6 +4,8 @@
 
 #include <vtbackend/ColorPalette.h>
 
+#include <vtpty/ImageSize.h>
+
 #include <text_shaper/font.h>
 
 #include <crispy/StrongHash.h>
@@ -14,6 +16,7 @@
 #include <QtCore/QFile>
 #include <QtGui/QOpenGLContext>
 
+#include <algorithm>
 #include <fstream>
 #include <iostream>
 
@@ -120,6 +123,10 @@ namespace
 
         locations.emplace_back("/usr/share/terminfo");
 
+        // BSD locations
+        locations.emplace_back("/usr/local/share/terminfo");
+        locations.emplace_back("/usr/local/share/site-terminfo");
+
         return locations;
     }
 
@@ -186,7 +193,7 @@ fs::path configHome()
 
 std::string createString(Config const& c)
 {
-    return createString(c, YAMLConfigWriter());
+    return createString<YAMLConfigWriter>(c);
 }
 
 std::string defaultConfigString()
@@ -212,6 +219,16 @@ error_code createDefaultConfig(fs::path const& path)
     return error_code {};
 }
 
+std::string documentationGlobalConfig()
+{
+    return documentationGlobalConfig<DocumentationWriter>(Config {});
+}
+
+std::string documentationProfileConfig()
+{
+    return documentationProfileConfig<DocumentationWriter>(Config {});
+}
+
 std::string defaultConfigFilePath()
 {
     return (configHome() / "contour.yml").string();
@@ -256,7 +273,7 @@ void compareEntries(Config& config, auto const& output)
 
     for (auto const& entry: existingEntries)
     {
-        if (std::find(userEntries.begin(), userEntries.end(), entry) == userEntries.end())
+        if (std::ranges::find(userEntries, entry) == userEntries.end())
         {
             output()("[diff] Entry {} is missing in user config file\n", entry);
         }
@@ -328,25 +345,20 @@ void YAMLConfigReader::load(Config& c)
             c.platformPlugin = "";
         }
         loadFromEntry("default_profile", c.defaultProfileName);
+        loadFromEntry("renderer", c.renderer);
         loadFromEntry("word_delimiters", c.wordDelimiters);
         loadFromEntry("extended_word_delimiters", c.extendedWordDelimiters);
         loadFromEntry("read_buffer_size", c.ptyReadBufferSize);
         loadFromEntry("pty_buffer_size", c.ptyBufferObjectSize);
-        loadFromEntry("images.sixel_register_count", c.maxImageColorRegisters);
+        loadFromEntry("images", c.images);
         loadFromEntry("live_config", c.live);
         loadFromEntry("early_exit_threshold", c.earlyExitThreshold);
         loadFromEntry("spawn_new_process", c.spawnNewProcess);
-        loadFromEntry("images.sixe_scrolling", c.sixelScrolling);
         loadFromEntry("reflow_on_resize", c.reflowOnResize);
         loadFromEntry("experimental", c.experimentalFeatures);
-        loadFromEntry("renderer.tile_direct_mapping", c.textureAtlasDirectMapping);
-        loadFromEntry("renderer.tile_hastable_slots", c.textureAtlasHashtableSlots);
-        loadFromEntry("renderer.tile_cache_count", c.textureAtlasTileCount);
-        loadFromEntry("renderer.backend", c.renderingBackend);
         loadFromEntry("bypass_mouse_protocol_modifier", c.bypassMouseProtocolModifiers);
         loadFromEntry("on_mouse_select", c.onMouseSelection);
         loadFromEntry("mouse_block_selection_modifier", c.mouseBlockSelectionModifiers);
-        loadFromEntry("images", c.maxImageSize);
         loadFromEntry("profiles", c.profiles, c.defaultProfileName.value());
         // loadFromEntry("color_schemes", c.colorschemes); // NB: This is always loaded lazily
         loadFromEntry("input_mapping", c.inputMappings);
@@ -364,39 +376,26 @@ void YAMLConfigReader::loadFromEntry(YAML::Node const& node, std::string const&
     auto const child = node[entry];
     if (child)
     {
-        // clang-format off
-        if (child["shell"])
-        {
-            loadFromEntry(child, "shell", where.shell);
-        }
-        else if (child["ssh"])
+        if (child["ssh"])
         {
             loadFromEntry(child, "ssh", where.ssh);
         }
         else
         {
-            // will create default shell if no shell nor ssh config is provided
+            // load shell config if ssh is not provided
             loadFromEntry(child, "shell", where.shell);
         }
         // inforce some default shell setup
         defaultSettings(where.shell.value());
 
-        loadFromEntry(child, "escape_sandbox", where.shell.value().escapeSandbox);
+        loadFromEntry(child, "escape_sandbox", where.escapeSandbox);
         loadFromEntry(child, "copy_last_mark_range_offset", where.copyLastMarkRangeOffset);
-        if(child["initial_working_directory"])
-            {
-                loadFromEntry(child, "initial_working_directory", where.shell.value().workingDirectory);
-            }
-        else
-            {
-                where.shell.value().workingDirectory = homeResolvedPath(where.shell.value().workingDirectory.generic_string(), Process::homeDirectory());
-            }
-
         loadFromEntry(child, "show_title_bar", where.showTitleBar);
         loadFromEntry(child, "size_indicator_on_resize", where.sizeIndicatorOnResize);
         loadFromEntry(child, "fullscreen", where.fullscreen);
         loadFromEntry(child, "maximized", where.maximized);
         loadFromEntry(child, "search_mode_switch", where.searchModeSwitch);
+        loadFromEntry(child, "insert_after_yank", where.insertAfterYank);
         loadFromEntry(child, "bell", where.bell);
         loadFromEntry(child, "wm_class", where.wmClass);
         loadFromEntry(child, "margins", where.margins);
@@ -404,27 +403,10 @@ void YAMLConfigReader::loadFromEntry(YAML::Node const& node, std::string const&
         loadFromEntry(child, "frozen_dec_modes", where.frozenModes);
         loadFromEntry(child, "slow_scrolling_time", where.smoothLineScrolling);
         loadFromEntry(child, "terminal_size", where.terminalSize);
-        if (child["history"])
-        {
-            loadFromEntry(child["history"], "limit", where.maxHistoryLineCount);
-            loadFromEntry(child["history"], "scroll_multiplier", where.historyScrollMultiplier);
-            loadFromEntry(child["history"], "auto_scroll_on_update", where.autoScrollOnUpdate);
-        }
-        if (child["scrollbar"])
-        {
-            loadFromEntry(child["scrollbar"], "position", where.scrollbarPosition);
-            loadFromEntry(child["scrollbar"], "hide_in_alt_screen", where.hideScrollbarInAltScreen);
-        }
-        if (child["mouse"])
-            loadFromEntry(child["mouse"], "hide_while_typing", where.mouseHideWhileTyping);
-        if (child["permissions"])
-        {
-            loadFromEntry(child["permissions"], "capture_buffer", where.captureBuffer);
-            loadFromEntry(child["permissions"], "change_font", where.changeFont);
-            loadFromEntry(child["permissions"],
-                          "display_host_writable_statusline",
-                          where.displayHostWritableStatusLine);
-        }
+        loadFromEntry(child, "history", where.history);
+        loadFromEntry(child, "scrollbar", where.scrollbar);
+        loadFromEntry(child, "mouse", where.mouse);
+        loadFromEntry(child, "permissions", where.permissions);
         loadFromEntry(child, "highlight_word_and_matches_on_double_click", where.highlightDoubleClickedWord);
         loadFromEntry(child, "font", where.fonts);
         loadFromEntry(child, "draw_bold_text_with_bright_colors", where.drawBoldTextWithBrightColors);
@@ -432,41 +414,36 @@ void YAMLConfigReader::loadFromEntry(YAML::Node const& node, std::string const&
         {
             loadFromEntry(child["cursor"], "shape", where.modeInsert.value().cursor.cursorShape);
             loadFromEntry(child["cursor"], "blinking", where.modeInsert.value().cursor.cursorDisplay);
-            loadFromEntry(child["cursor"], "blinking_interval", where.modeInsert.value().cursor.cursorBlinkInterval);
+            loadFromEntry(
+                child["cursor"], "blinking_interval", where.modeInsert.value().cursor.cursorBlinkInterval);
         }
         if (child["normal_mode"] && child["normal_mode"]["cursor"])
         {
-            loadFromEntry(child["normal_mode"]["cursor"], "shape", where.modeNormal.value().cursor.cursorShape);
-            loadFromEntry(child["normal_mode"]["cursor"], "blinking", where.modeNormal.value().cursor.cursorDisplay);
-            loadFromEntry(child["normal_mode"]["cursor"], "blinking_interval", where.modeNormal.value().cursor.cursorBlinkInterval);
+            loadFromEntry(
+                child["normal_mode"]["cursor"], "shape", where.modeNormal.value().cursor.cursorShape);
+            loadFromEntry(
+                child["normal_mode"]["cursor"], "blinking", where.modeNormal.value().cursor.cursorDisplay);
+            loadFromEntry(child["normal_mode"]["cursor"],
+                          "blinking_interval",
+                          where.modeNormal.value().cursor.cursorBlinkInterval);
         }
         if (child["visual_mode"] && child["visual_mode"]["cursor"])
         {
-            loadFromEntry(child["visual_mode"]["cursor"], "shape", where.modeVisual.value().cursor.cursorShape);
-            loadFromEntry(child["visual_mode"]["cursor"], "blinking", where.modeVisual.value().cursor.cursorDisplay);
-            loadFromEntry(child["visual_mode"]["cursor"], "blinking_interval", where.modeVisual.value().cursor.cursorBlinkInterval);
-            loadFromEntry(child["visual_mode"]["cursor"], "blinking_interval", where.modeVisual.value().cursor.cursorBlinkInterval);
+            loadFromEntry(
+                child["visual_mode"]["cursor"], "shape", where.modeVisual.value().cursor.cursorShape);
+            loadFromEntry(
+                child["visual_mode"]["cursor"], "blinking", where.modeVisual.value().cursor.cursorDisplay);
+            loadFromEntry(child["visual_mode"]["cursor"],
+                          "blinking_interval",
+                          where.modeVisual.value().cursor.cursorBlinkInterval);
+            loadFromEntry(child["visual_mode"]["cursor"],
+                          "blinking_interval",
+                          where.modeVisual.value().cursor.cursorBlinkInterval);
         }
         loadFromEntry(child, "vi_mode_highlight_timeout", where.highlightTimeout);
         loadFromEntry(child, "vi_mode_scrolloff", where.modalCursorScrollOff);
-        if (child["status_line"])
-        {
-            loadFromEntry(child["status_line"], "position", where.statusDisplayPosition);
-            loadFromEntry(child["status_line"], "sync_to_window_title", where.syncWindowTitleWithHostWritableStatusDisplay);
-            loadFromEntry(child["status_line"], "display", where.initialStatusDisplayType);
-
-            if (child["status_line"]["indicator"])
-            {
-                loadFromEntry(child["status_line"]["indicator"], "left", where.indicatorStatusLineLeft);
-                loadFromEntry(child["status_line"]["indicator"], "middle", where.indicatorStatusLineMiddle);
-                loadFromEntry(child["status_line"]["indicator"], "right", where.indicatorStatusLineRight);
-            }
-        }
-        if (child["background"])
-        {
-            loadFromEntry(child["background"], "opacity", where.backgroundOpacity);
-            loadFromEntry(child["background"], "blur", where.backgroundBlur);
-        }
+        loadFromEntry(child, "status_line", where.statusLine);
+        loadFromEntry(child, "background", where.background);
         // clang-format on
 
         loadFromEntry(child, "colors", where.colors);
@@ -479,8 +456,7 @@ void YAMLConfigReader::loadFromEntry(YAML::Node const& node, std::string const&
             dual->lightMode.useBrightColors = where.drawBoldTextWithBrightColors.value();
         }
 
-        loadFromEntry(child, "hyperlink_decoration.normal", where.hyperlinkDecorationNormal);
-        loadFromEntry(child, "hyperlink_decoration.hover", where.hyperlinkDecorationHover);
+        loadFromEntry(child, "hyperlink_decoration", where.hyperlinkDecoration);
     }
 }
 
@@ -862,11 +838,21 @@ void YAMLConfigReader::loadFromEntry(YAML::Node const& node,
     {
         where.program = child.as<std::string>();
     }
+    // loading arguments from the profile
     if (auto args = node["arguments"]; args && args.IsSequence())
     {
         for (auto const& argNode: args)
             where.arguments.emplace_back(argNode.as<string>());
     }
+    if (node["initial_working_directory"])
+    {
+        loadFromEntry(node, "initial_working_directory", where.workingDirectory);
+    }
+    else
+    {
+        where.workingDirectory =
+            homeResolvedPath(where.workingDirectory.generic_string(), Process::homeDirectory());
+    }
 }
 
 void YAMLConfigReader::loadFromEntry(YAML::Node const& node,
@@ -1090,6 +1076,119 @@ void YAMLConfigReader::loadFromEntry(YAML::Node const& node,
     }
 }
 
+void YAMLConfigReader::loadFromEntry(YAML::Node const& node, std::string const& entry, RendererConfig& where)
+{
+    auto const child = node[entry];
+    if (child)
+    {
+        loadFromEntry(child, "tile_direct_mapping", where.textureAtlasDirectMapping);
+        loadFromEntry(child, "tile_hashtable_slots", where.textureAtlasHashtableSlots);
+        loadFromEntry(child, "tile_cache_count", where.textureAtlasTileCount);
+        loadFromEntry(child, "backend", where.renderingBackend);
+    }
+}
+
+void YAMLConfigReader::loadFromEntry(YAML::Node const& node, std::string const& entry, ImagesConfig& where)
+{
+    auto const child = node[entry];
+    if (child)
+    {
+        loadFromEntry(child, "sixel_scrolling", where.sixelScrolling);
+        loadFromEntry(child, "sixel_register_count", where.maxImageColorRegisters);
+        uint width = 0;
+        loadFromEntry(child, "max_width", width);
+        uint height = 0;
+        loadFromEntry(child, "max_height", height);
+        where.maxImageSize = { .width = vtpty::Width { width }, .height = vtpty::Height { height } };
+    }
+}
+
+void YAMLConfigReader::loadFromEntry(YAML::Node const& node, std::string const& entry, HistoryConfig& where)
+{
+    auto const child = node[entry];
+    if (child)
+    {
+        loadFromEntry(child, "limit", where.maxHistoryLineCount);
+        loadFromEntry(child, "scroll_multiplier", where.historyScrollMultiplier);
+        loadFromEntry(child, "auto_scroll_on_update", where.autoScrollOnUpdate);
+    }
+}
+
+void YAMLConfigReader::loadFromEntry(YAML::Node const& node, std::string const& entry, ScrollBarConfig& where)
+{
+    auto const child = node[entry];
+    if (child)
+    {
+        loadFromEntry(child, "position", where.position);
+        loadFromEntry(child, "hide_in_alt_screen", where.hideScrollbarInAltScreen);
+    }
+}
+
+void YAMLConfigReader::loadFromEntry(YAML::Node const& node, std::string const& entry, MouseConfig& where)
+{
+    auto const child = node[entry];
+    if (child)
+    {
+        loadFromEntry(child, "hide_while_typing", where.hideWhileTyping);
+    }
+}
+
+void YAMLConfigReader::loadFromEntry(YAML::Node const& node,
+                                     std::string const& entry,
+                                     StatusLineConfig& where)
+{
+    auto const child = node[entry];
+    if (child)
+    {
+        loadFromEntry(child, "position", where.position);
+        loadFromEntry(child, "sync_to_window_title", where.syncWindowTitleWithHostWritableStatusDisplay);
+        loadFromEntry(child, "display", where.initialType);
+        if (child["indicator"])
+        {
+            loadFromEntry(child["indicator"], "left", where.indicator.left);
+            loadFromEntry(child["indicator"], "middle", where.indicator.middle);
+            loadFromEntry(child["indicator"], "right", where.indicator.right);
+        }
+    }
+}
+
+void YAMLConfigReader::loadFromEntry(YAML::Node const& node,
+                                     std::string const& entry,
+                                     BackgroundConfig& where)
+{
+    auto const child = node[entry];
+    if (child)
+    {
+        loadFromEntry(child, "opacity", where.opacity);
+        loadFromEntry(child, "blur", where.blur);
+    }
+}
+
+void YAMLConfigReader::loadFromEntry(YAML::Node const& node,
+                                     std::string const& entry,
+                                     HyperlinkDecorationConfig& where)
+{
+    auto const child = node[entry];
+    if (child)
+    {
+        loadFromEntry(child, "normal", where.normal);
+        loadFromEntry(child, "hover", where.hover);
+    }
+}
+
+void YAMLConfigReader::loadFromEntry(YAML::Node const& node,
+                                     std::string const& entry,
+                                     PermissionsConfig& where)
+{
+    auto const child = node[entry];
+    if (child)
+    {
+        loadFromEntry(child, "capture_buffer", where.captureBuffer);
+        loadFromEntry(child, "change_font", where.changeFont);
+        loadFromEntry(child, "display_host_writable_statusline", where.displayHostWritableStatusLine);
+    }
+}
+
 void YAMLConfigReader::loadFromEntry(YAML::Node const& node, std::string const& entry, ColorConfig& where)
 {
     if (auto const child = node[entry])
@@ -1162,7 +1261,7 @@ void YAMLConfigReader::loadFromEntry(YAML::Node const& node,
         {
             if (literal == deprecated)
             {
-                errorLog()("Setting font locator to \"{}\" is deprecated. Use \"native\".", literal);
+                errorLog()(R"(Setting font locator to "{}" is deprecated. Use "native".)", literal);
                 return NativeFontLocator;
             }
         }
@@ -1705,6 +1804,7 @@ std::optional<vtbackend::Modifiers> YAMLConfigReader::parseModifierKey(std::stri
     return std::nullopt;
 }
 
+// NOLINTNEXTLINE(readability-function-cognitive-complexity)
 std::optional<actions::Action> YAMLConfigReader::parseAction(YAML::Node const& node)
 {
     if (auto actionNode = node["action"])
@@ -1727,6 +1827,16 @@ std::optional<actions::Action> YAMLConfigReader::parseAction(YAML::Node const& n
                 return std::nullopt;
         }
 
+        if (holds_alternative<actions::SwitchToTab>(action))
+        {
+            if (auto position = node["position"]; position.IsScalar())
+            {
+                return actions::SwitchToTab { position.as<int>() };
+            }
+            else
+                return std::nullopt;
+        }
+
         if (holds_alternative<actions::NewTerminal>(action))
         {
             if (auto profile = node["profile"]; profile && profile.IsScalar())
@@ -1953,211 +2063,135 @@ void YAMLConfigReader::loadFromEntry(YAML::Node const& node,
 }
 
 template <typename Writer>
-std::string createString(Config const& c)
+std::string createForGlobal(Config const& c)
 {
     auto doc = std::string {};
     Writer writer;
-    auto const process = [&](auto v) {
-        doc.append(writer.process(v.documentation, v.value()));
+
+    auto const escapeSequence = [&](std::string const& value) {
+        /* \ -> \\ */
+        /* " -> \" */
+        return std::regex_replace(
+            std::regex_replace(value, std::regex("\\\\"), "\\$&"), std::regex("\""), "\\$&");
     };
 
-    auto const processWithDoc = [&](auto&& docString, auto... val) {
-        doc.append(helper::replaceCommentPlaceholder(writer.process(docString.value, val...)));
+    auto const processConfigEntry =
+        [&]<typename T, documentation::StringLiteral ConfigDoc, documentation::StringLiteral WebDoc>(
+            auto name,
+            contour::config::ConfigEntry<
+                T,
+                contour::config::documentation::DocumentationEntry<ConfigDoc, WebDoc>> const& v) {
+            doc.append(writer.process(writer.whichDoc(v), name, v.value()));
+        };
+
+    auto const processConfigEntryWithEscape =
+        [&]<documentation::StringLiteral ConfigDoc, documentation::StringLiteral WebDoc>(
+            auto name,
+            contour::config::ConfigEntry<
+                std::string,
+                contour::config::documentation::DocumentationEntry<ConfigDoc, WebDoc>> const& v) {
+            doc.append(writer.process(writer.whichDoc(v), name, escapeSequence(v.value())));
+        };
+
+    auto completeOverload = crispy::overloaded {
+        processConfigEntry,
+        processConfigEntryWithEscape,
+        // Ignored entries
+        [&]([[maybe_unused]] auto name,
+            [[maybe_unused]] ConfigEntry<std::unordered_map<std::string, vtbackend::ColorPalette>,
+                                         documentation::ColorSchemes> const& v) {},
+        [&]([[maybe_unused]] auto name,
+            [[maybe_unused]] ConfigEntry<std::map<vtbackend::DECMode, bool>,
+                                         documentation::FrozenDecMode> const& v) {},
+        [&]([[maybe_unused]] auto name,
+            [[maybe_unused]] ConfigEntry<InputMappings, documentation::InputMappings> const& v) {},
+        [&]([[maybe_unused]] auto name,
+            [[maybe_unused]] ConfigEntry<std::unordered_map<std::string, TerminalProfile>,
+                                         documentation::Profiles> const& v) {},
+        [&]([[maybe_unused]] auto name, [[maybe_unused]] auto const& v) {},
     };
 
-    auto const processWordDelimiters = [&]() {
-        auto wordDelimiters = c.wordDelimiters.value();
-        wordDelimiters = std::regex_replace(wordDelimiters, std::regex("\\\\"), "\\$&"); /* \ -> \\ */
-        wordDelimiters = std::regex_replace(wordDelimiters, std::regex("\""), "\\$&");   /* " -> \" */
-        doc.append(helper::replaceCommentPlaceholder(
-            writer.process(documentation::WordDelimiters.value, wordDelimiters)));
+    Reflection::CallOnMembers(c, completeOverload);
+
+    return doc;
+}
+
+template <typename Writer>
+std::string createForProfile(Config const& c)
+{
+    auto doc = std::string {};
+    Writer writer;
+
+    auto const processConfigEntry =
+        [&]<typename T, documentation::StringLiteral ConfigDoc, documentation::StringLiteral WebDoc>(
+            auto name,
+            contour::config::ConfigEntry<
+                T,
+                contour::config::documentation::DocumentationEntry<ConfigDoc, WebDoc>> const& v) {
+            doc.append(writer.process(writer.whichDoc(v), name, v.value()));
+        };
+
+    // Something is wrong for vtpty::Process::ExecInfo formating for static build
+    // we add this lambda to handle it in overload set for now
+    auto const processConfigEntryWithExecInfo =
+        [&]<documentation::StringLiteral ConfigDoc, documentation::StringLiteral WebDoc>(
+            auto name,
+            contour::config::ConfigEntry<
+                vtpty::Process::ExecInfo,
+                contour::config::documentation::DocumentationEntry<ConfigDoc, WebDoc>> const& vEntry) {
+            auto v = vEntry.value();
+            auto args = std::string { "[" };
+            args.append(v.arguments | ::ranges::views::join(", ") | ::ranges::to<std::string>);
+            args.append("]");
+
+            doc.append(writer.process(writer.whichDoc(vEntry), name, v.program, args, [&]() -> std::string {
+                auto fromConfig = v.workingDirectory.string();
+                if (fromConfig.empty()
+                    || fromConfig == crispy::homeResolvedPath("~", vtpty::Process::homeDirectory()))
+                    return std::string { "\"~\"" };
+                return fromConfig;
+            }()));
+        };
+
+    auto completeOverload = crispy::overloaded {
+        processConfigEntryWithExecInfo,
+        processConfigEntry,
+        [&]([[maybe_unused]] auto name, [[maybe_unused]] auto const& v) {},
     };
 
-    auto const processExtendedWordDelimiters = [&]() {
-        auto wordDelimiters = c.extendedWordDelimiters.value();
-        wordDelimiters = std::regex_replace(wordDelimiters, std::regex("\\\\"), "\\$&"); /* \ -> \\ */
-        wordDelimiters = std::regex_replace(wordDelimiters, std::regex("\""), "\\$&");   /* " -> \" */
-        doc.append(helper::replaceCommentPlaceholder(
-            writer.process(documentation::ExtendedWordDelimiters.value, wordDelimiters)));
-    };
-
-    if (c.platformPlugin.value().empty())
-    {
-        processWithDoc(documentation::PlatformPlugin, std::string { "auto" });
-    }
-    else
-    {
-        process(c.platformPlugin);
-    }
-
-    // inside renderer:
-    writer.scoped([&]() {
-        doc.append("renderer: \n");
-        process(c.renderingBackend);
-        process(c.textureAtlasHashtableSlots);
-        process(c.textureAtlasTileCount);
-        process(c.textureAtlasDirectMapping);
-    });
-
-    processWordDelimiters();
-    processExtendedWordDelimiters();
-    process(c.ptyReadBufferSize);
-    process(c.ptyBufferObjectSize);
-    process(c.defaultProfileName);
-    process(c.earlyExitThreshold);
-    process(c.spawnNewProcess);
-    process(c.reflowOnResize);
-    process(c.bypassMouseProtocolModifiers);
-    process(c.mouseBlockSelectionModifiers);
-    process(c.onMouseSelection);
-    process(c.live);
-    process(c.experimentalFeatures);
-
-    // inside images:
-    doc.append("\nimages: \n");
-
-    writer.scoped([&]() {
-        process(c.sixelScrolling);
-        process(c.maxImageColorRegisters);
-        process(c.maxImageSize);
-    });
-
     // inside profiles:
-    doc.append(helper::replaceCommentPlaceholder(c.profiles.documentation));
+    doc.append(writer.replaceCommentPlaceholder(std::string { writer.whichDoc(c.profiles) }));
     {
         const auto _ = typename Writer::Offset {};
         for (auto&& [name, entry]: c.profiles.value())
         {
-            doc.append(std::format("    {}: \n", name));
-            {
-                const auto _ = typename Writer::Offset {};
-                process(entry.shell);
-                process(entry.ssh);
+            if constexpr (std::same_as<Writer, YAMLConfigWriter>)
+                doc.append(std::format("    {}: \n", name));
 
-                processWithDoc(documentation::EscapeSandbox, entry.shell.value().escapeSandbox);
-                process(entry.copyLastMarkRangeOffset);
-                processWithDoc(documentation::InitialWorkingDirectory, [&entry = entry]() {
-                    auto fromConfig = entry.shell.value().workingDirectory.string();
-                    if (fromConfig.empty() || fromConfig == homeResolvedPath("~", Process::homeDirectory()))
-                        return std::string { "\"~\"" };
-                    return fromConfig;
-                }());
-                process(entry.showTitleBar);
-                process(entry.sizeIndicatorOnResize);
-                process(entry.fullscreen);
-                process(entry.maximized);
-                process(entry.searchModeSwitch);
-                process(entry.bell);
-                process(entry.wmClass);
-                process(entry.terminalId);
-                processWithDoc(documentation::FrozenDecMode, 0);
-                process(entry.smoothLineScrolling);
-                process(entry.terminalSize);
-
-                process(entry.margins);
-                // history: section
-                doc.append(Writer::addOffset("history:\n", Writer::Offset::levels * Writer::OneOffset));
-                {
-                    const auto _ = typename Writer::Offset {};
-                    process(entry.maxHistoryLineCount);
-                    process(entry.autoScrollOnUpdate);
-                    process(entry.historyScrollMultiplier);
-                }
-
-                // scrollbar: section
-                doc.append(Writer::addOffset("scrollbar:\n", Writer::Offset::levels * Writer::OneOffset));
-                ;
-                {
-                    const auto _ = typename Writer::Offset {};
-                    process(entry.scrollbarPosition);
-                    process(entry.hideScrollbarInAltScreen);
-                }
-
-                // mouse: section
-                doc.append(Writer::addOffset("mouse:\n", Writer::Offset::levels * Writer::OneOffset));
-                {
-                    const auto _ = typename Writer::Offset {};
-                    process(entry.mouseHideWhileTyping);
-                }
-
-                //  permissions: section
-                processWithDoc(
-                    documentation::StringLiteral {
-                        "\n"
-                        "{comment} Some VT sequences should need access permissions.\n"
-                        "{comment} \n"
-                        "{comment}  These can be to:\n"
-                        "{comment}  - allow     Allows the given functionality\n"
-                        "{comment}  - deny      Denies the given functionality\n"
-                        "{comment}  - ask       Asks the user interactively via popup dialog for "
-                        "permission of the given action.\n"
-                        "permissions:\n" },
-                    0);
-                {
-                    const auto _ = typename Writer::Offset {};
-                    process(entry.changeFont);
-                    process(entry.captureBuffer);
-                    process(entry.displayHostWritableStatusLine);
-                }
-                process(entry.highlightDoubleClickedWord);
-                process(entry.fonts);
-                process(entry.drawBoldTextWithBrightColors);
-                process(entry.modeInsert);
-                process(entry.modeNormal);
-                process(entry.modeVisual);
-                process(entry.highlightTimeout);
-                process(entry.modalCursorScrollOff);
-
-                // status_line
-                doc.append(Writer::addOffset("\n"
-                                             "status_line:\n",
-                                             Writer::Offset::levels * Writer::OneOffset));
-                {
-                    const auto _ = typename Writer::Offset {};
-                    process(entry.initialStatusDisplayType);
-                    process(entry.statusDisplayPosition);
-                    process(entry.syncWindowTitleWithHostWritableStatusDisplay);
-
-                    doc.append(Writer::addOffset("indicator:\n", Writer::Offset::levels * Writer::OneOffset));
-                    {
-                        const auto _ = typename Writer::Offset {};
-                        process(entry.indicatorStatusLineLeft);
-                        process(entry.indicatorStatusLineMiddle);
-                        process(entry.indicatorStatusLineRight);
-                    }
-                }
-
-                doc.append(Writer::addOffset("\n"
-                                             "background:\n",
-                                             Writer::Offset::levels * Writer::OneOffset));
-                {
-                    const auto _ = typename Writer::Offset {};
-                    process(entry.backgroundOpacity);
-                    process(entry.backgroundBlur);
-                }
-
-                process(entry.colors);
-
-                doc.append(Writer::addOffset("\n"
-                                             "hyperlink_decoration:\n",
-                                             Writer::Offset::levels * Writer::OneOffset));
-                {
-                    const auto _ = typename Writer::Offset {};
-                    process(entry.hyperlinkDecorationNormal);
-                    process(entry.hyperlinkDecorationHover);
-                }
-            }
-        };
+            writer.scoped([&]() { Reflection::CallOnMembers(entry, completeOverload); });
+        }
     }
+    return doc;
+}
 
-    doc.append(helper::replaceCommentPlaceholder(c.colorschemes.documentation));
+template <typename Writer>
+std::string createForColorScheme(Config const& c)
+{
+    auto doc = std::string {};
+    Writer writer;
+
+    auto const processWithDoc = [&](auto&& docString, auto... val) {
+        doc.append(writer.replaceCommentPlaceholder(writer.process(writer.whichDoc(docString), val...)));
+    };
+
+    doc.append(writer.replaceCommentPlaceholder(c.colorschemes.documentation));
     writer.scoped([&]() {
         for (auto&& [name, entry]: c.colorschemes.value())
         {
             doc.append(std::format("    {}: \n", name));
             {
                 const auto _ = typename Writer::Offset {};
-                processWithDoc(documentation::DefaultColors,
+                processWithDoc(documentation::DefaultColors {},
                                entry.defaultBackground,
                                entry.defaultForeground,
                                entry.defaultForegroundBright,
@@ -2193,63 +2227,63 @@ std::string createString(Config const& c)
                 //                covered otherwise.\n" "    #\n" "    text: {}\n",
                 //                entry.cursor.color, entry.cursor.textOverrideColor);
 
-                processWithDoc(documentation::HyperlinkDecoration,
+                processWithDoc(documentation::HyperlinkDecoration {},
                                entry.hyperlinkDecoration.normal,
                                entry.hyperlinkDecoration.hover);
 
-                processWithDoc(documentation::YankHighlight,
+                processWithDoc(documentation::YankHighlight {},
                                entry.yankHighlight.foreground,
                                entry.yankHighlight.foregroundAlpha,
                                entry.yankHighlight.background,
                                entry.yankHighlight.backgroundAlpha);
 
-                processWithDoc(documentation::NormalModeCursorline,
+                processWithDoc(documentation::NormalModeCursorline {},
                                entry.normalModeCursorline.foreground,
                                entry.normalModeCursorline.foregroundAlpha,
                                entry.normalModeCursorline.background,
                                entry.normalModeCursorline.backgroundAlpha);
 
-                processWithDoc(documentation::Selection,
+                processWithDoc(documentation::Selection {},
                                entry.selection.foreground,
                                entry.selection.foregroundAlpha,
                                entry.selection.background,
                                entry.selection.backgroundAlpha);
 
-                processWithDoc(documentation::SearchHighlight,
+                processWithDoc(documentation::SearchHighlight {},
                                entry.searchHighlight.foreground,
                                entry.searchHighlight.foregroundAlpha,
                                entry.searchHighlight.background,
                                entry.searchHighlight.backgroundAlpha);
 
-                processWithDoc(documentation::SearchHighlihtFocused,
+                processWithDoc(documentation::SearchHighlightFocused {},
                                entry.searchHighlightFocused.foreground,
                                entry.searchHighlightFocused.foregroundAlpha,
                                entry.searchHighlightFocused.background,
                                entry.searchHighlightFocused.backgroundAlpha);
 
-                processWithDoc(documentation::WordHighlightCurrent,
+                processWithDoc(documentation::WordHighlightCurrent {},
                                entry.wordHighlightCurrent.foreground,
                                entry.wordHighlightCurrent.foregroundAlpha,
                                entry.wordHighlightCurrent.background,
                                entry.wordHighlightCurrent.backgroundAlpha);
 
-                processWithDoc(documentation::WordHighlight,
+                processWithDoc(documentation::WordHighlight {},
                                entry.wordHighlight.foreground,
                                entry.wordHighlight.foregroundAlpha,
                                entry.wordHighlight.background,
                                entry.wordHighlight.backgroundAlpha);
 
-                processWithDoc(documentation::IndicatorStatusLine,
+                processWithDoc(documentation::IndicatorStatusLine {},
                                entry.indicatorStatusLineInsertMode.foreground,
                                entry.indicatorStatusLineInsertMode.background,
                                entry.indicatorStatusLineInactive.foreground,
                                entry.indicatorStatusLineInactive.background);
 
-                processWithDoc(documentation::InputMethodEditor,
+                processWithDoc(documentation::InputMethodEditor {},
                                entry.inputMethodEditor.foreground,
                                entry.inputMethodEditor.background);
 
-                processWithDoc(documentation::NormalColors,
+                processWithDoc(documentation::NormalColors {},
                                entry.normalColor(0),
                                entry.normalColor(1),
                                entry.normalColor(2),
@@ -2259,7 +2293,7 @@ std::string createString(Config const& c)
                                entry.normalColor(6),
                                entry.normalColor(7));
 
-                processWithDoc(documentation::BrightColors,
+                processWithDoc(documentation::BrightColors {},
                                entry.brightColor(0),
                                entry.brightColor(1),
                                entry.brightColor(2),
@@ -2269,7 +2303,7 @@ std::string createString(Config const& c)
                                entry.brightColor(6),
                                entry.brightColor(7));
 
-                processWithDoc(documentation::DimColors,
+                processWithDoc(documentation::DimColors {},
                                entry.dimColor(0),
                                entry.dimColor(1),
                                entry.dimColor(2),
@@ -2282,7 +2316,16 @@ std::string createString(Config const& c)
         }
     });
 
-    doc.append(helper::replaceCommentPlaceholder(c.inputMappings.documentation));
+    return doc;
+}
+
+template <typename Writer>
+std::string createKeyMapping(Config const& c)
+{
+    auto doc = std::string {};
+    Writer writer;
+
+    doc.append(writer.replaceCommentPlaceholder(c.inputMappings.documentation));
     {
         const auto _ = typename Writer::Offset {};
         for (auto&& entry: c.inputMappings.value().keyMappings)
@@ -2294,7 +2337,27 @@ std::string createString(Config const& c)
         for (auto&& entry: c.inputMappings.value().mouseMappings)
             doc.append(Writer::addOffset(writer.format(entry), Writer::Offset::levels * Writer::OneOffset));
     }
+
     return doc;
 }
 
+template <typename Writer>
+std::string documentationGlobalConfig(Config const& c)
+{
+    return createForGlobal<Writer>(c);
+}
+
+template <typename Writer>
+std::string documentationProfileConfig(Config const& c)
+{
+    return createForProfile<Writer>(c);
+}
+
+template <typename Writer>
+std::string createString(Config const& c)
+{
+    return createForGlobal<Writer>(c) + createForProfile<Writer>(c) + createForColorScheme<Writer>(c)
+           + createKeyMapping<Writer>(c);
+}
+
 } // namespace contour::config
