@@ -41,6 +41,7 @@ enum class GuardedRole : uint8_t
     ChangeFont,
     CaptureBuffer,
     ShowHostWritableStatusLine,
+    BigPaste,
 };
 
 /**
@@ -108,7 +109,7 @@ class TerminalSession: public QAbstractItemModel, public vtbackend::Terminal::Ev
     int getFontSize() const noexcept { return static_cast<int>(_profile.fonts.value().size.pt); }
     float getOpacity() const noexcept
     {
-        return static_cast<float>(_profile.backgroundOpacity.value()) / std::numeric_limits<uint8_t>::max();
+        return static_cast<float>(_profile.background.value().opacity) / std::numeric_limits<uint8_t>::max();
     }
     QString pathToBackground() const
     {
@@ -125,7 +126,7 @@ class TerminalSession: public QAbstractItemModel, public vtbackend::Terminal::Ev
         auto color = terminal().isModeEnabled(vtbackend::DECMode::ReverseVideo)
                          ? _terminal.colorPalette().defaultForeground
                          : _terminal.colorPalette().defaultBackground;
-        auto alpha = static_cast<uint8_t>(_profile.backgroundOpacity.value());
+        auto alpha = static_cast<uint8_t>(_profile.background.value().opacity);
         return QColor(color.red, color.green, color.blue, alpha);
     }
     float getOpacityBackground() const noexcept
@@ -156,16 +157,16 @@ class TerminalSession: public QAbstractItemModel, public vtbackend::Terminal::Ev
 
     bool getIsScrollbarRight() const noexcept
     {
-        return profile().scrollbarPosition.value() == config::ScrollBarPosition::Right;
+        return profile().scrollbar.value().position == config::ScrollBarPosition::Right;
     }
 
     bool getIsScrollbarVisible() const noexcept
     {
-        if (profile().scrollbarPosition.value() == config::ScrollBarPosition::Hidden)
+        if (profile().scrollbar.value().position == config::ScrollBarPosition::Hidden)
             return false;
 
         if ((_currentScreenType == vtbackend::ScreenType::Alternate)
-            && profile().hideScrollbarInAltScreen.value())
+            && profile().scrollbar.value().hideScrollbarInAltScreen)
             return false;
 
         return true;
@@ -228,9 +229,6 @@ class TerminalSession: public QAbstractItemModel, public vtbackend::Terminal::Ev
     config::Config const& config() const noexcept { return _config; }
     config::TerminalProfile const& profile() const noexcept { return _profile; }
 
-    double contentScale() const noexcept { return _contentScale; }
-    void setContentScale(double value) noexcept { _contentScale = value; }
-
     vtpty::Pty& pty() noexcept { return _terminal.device(); }
     vtbackend::Terminal& terminal() noexcept { return _terminal; }
     vtbackend::Terminal const& terminal() const noexcept { return _terminal; }
@@ -243,9 +241,10 @@ class TerminalSession: public QAbstractItemModel, public vtbackend::Terminal::Ev
     void detachDisplay(display::TerminalDisplay& display);
 
     Q_INVOKABLE void applyPendingFontChange(bool allow, bool remember);
+    Q_INVOKABLE void applyPendingPaste(bool allow, bool remember);
     Q_INVOKABLE void executePendingBufferCapture(bool allow, bool remember);
     Q_INVOKABLE void executeShowHostWritableStatusLine(bool allow, bool remember);
-    Q_INVOKABLE void adaptToWidgetSize();
+    Q_INVOKABLE void resizeTerminalToDisplaySize();
 
     void updateColorPreference(vtbackend::ColorPreference preference);
 
@@ -330,6 +329,8 @@ class TerminalSession: public QAbstractItemModel, public vtbackend::Terminal::Ev
     bool operator()(actions::ResetConfig);
     bool operator()(actions::ResetFontSize);
     bool operator()(actions::ScreenshotVT);
+    bool operator()(actions::CopyScreenshot);
+    bool operator()(actions::SaveScreenshot);
     bool operator()(actions::ScrollDown);
     bool operator()(actions::ScrollMarkDown);
     bool operator()(actions::ScrollMarkUp);
@@ -353,6 +354,12 @@ class TerminalSession: public QAbstractItemModel, public vtbackend::Terminal::Ev
     bool operator()(actions::TraceStep);
     bool operator()(actions::ViNormalMode);
     bool operator()(actions::WriteScreen const& event);
+    bool operator()(actions::CreateNewTab);
+    bool operator()(actions::CloseTab);
+    bool operator()(actions::SwitchToTab const& event);
+    bool operator()(actions::SwitchToPreviousTab);
+    bool operator()(actions::SwitchToTabLeft);
+    bool operator()(actions::SwitchToTabRight);
 
     void scheduleRedraw();
 
@@ -391,11 +398,20 @@ class TerminalSession: public QAbstractItemModel, public vtbackend::Terminal::Ev
     void onBell(float volume);
     void onAlert();
     void requestPermissionForFontChange();
+    void requestPermissionForPasteLargeFile();
     void requestPermissionForBufferCapture();
     void requestPermissionForShowHostWritableStatusLine();
     void showNotification(QString const& title, QString const& content);
     void fontSizeChanged();
 
+    // Tab handling signals
+    void createNewTab();
+    void closeTab();
+    void switchToPreviousTab();
+    void switchToTabLeft();
+    void switchToTabRight();
+    void switchToTab(int position);
+
   public slots:
     void onConfigReload();
     void onHighlightUpdate();
@@ -426,7 +442,6 @@ class TerminalSession: public QAbstractItemModel, public vtbackend::Terminal::Ev
     config::Config _config;
     std::string _profileName;
     config::TerminalProfile _profile;
-    double _contentScale = 1.0;
     ContourGuiApp& _app;
     vtbackend::ColorPreference _currentColorPreference;
 
@@ -460,6 +475,7 @@ class TerminalSession: public QAbstractItemModel, public vtbackend::Terminal::Ev
     };
     std::optional<CaptureBufferRequest> _pendingBufferCapture;
     std::optional<vtbackend::FontDef> _pendingFontChange;
+    std::optional<QClipboard*> _pendingBigPaste;
     PermissionCache _rememberedPermissions;
     std::unique_ptr<QThread> _exitWatcherThread;
 
@@ -484,6 +500,7 @@ struct std::formatter<contour::GuardedRole>: std::formatter<std::string_view>
             case contour::GuardedRole::ChangeFont: output = "Change Font"; break;
             case contour::GuardedRole::CaptureBuffer: output = "Capture Buffer"; break;
             case contour::GuardedRole::ShowHostWritableStatusLine:  output = "show Host Writable Statusline"; break;
+            case contour::GuardedRole::BigPaste:  output = "paste large number of characters"; break;
         }
         // clang-format on
         return formatter<string_view>::format(output, ctx);
