@@ -40,6 +40,7 @@
 #include <fstream>
 #include <string_view>
 #include <tuple>
+#include <variant>
 #include <vector>
 
 namespace fs = std::filesystem;
@@ -218,6 +219,19 @@ namespace
         return nullopt;
     }
 
+    QScreen* findScreenWithBiggestWidth(QScreen* startScreen)
+    {
+        auto* screenToUse = startScreen;
+        for (auto* screen: startScreen->virtualSiblings())
+        {
+            if (screen->size().width() > screenToUse->size().width())
+            {
+                screenToUse = screen;
+            }
+        }
+        return screenToUse;
+    }
+
 } // namespace
 // }}}
 
@@ -264,11 +278,12 @@ TerminalDisplay::~TerminalDisplay()
 
 void TerminalDisplay::setSession(TerminalSession* newSession)
 {
-    if (_session)
+    displayLog()("TerminalDisplay::setSession: {} -> {}\n", (void*) _session, (void*) newSession);
+    if (_session == newSession)
         return;
 
     // This will print the same pointer address for `this` but a new one for newSession (model data).
-    displayLog()("Assigning session to terminal widget({} <- {}): shell={}, terminalSize={}, fontSize={}, "
+    displayLog()("Assigning session to display({} <- {}): shell={}, terminalSize={}, fontSize={}, "
                  "contentScale={}",
                  (void const*) this,
                  (void const*) newSession,
@@ -282,6 +297,11 @@ void TerminalDisplay::setSession(TerminalSession* newSession)
                  newSession->profile().fonts.value().size,
                  contentScale());
 
+    if (_session)
+    {
+        QObject::disconnect(_session, &TerminalSession::titleChanged, this, &TerminalDisplay::titleChanged);
+    }
+
     _session = newSession;
 
     QObject::connect(newSession, &TerminalSession::titleChanged, this, &TerminalDisplay::titleChanged);
@@ -290,21 +310,26 @@ void TerminalDisplay::setSession(TerminalSession* newSession)
 
     window()->setFlag(Qt::FramelessWindowHint, !profile().showTitleBar.value());
 
-    _renderer =
-        make_unique<vtrasterizer::Renderer>(newSession->profile().terminalSize.value(),
-                                            sanitizeFontDescription(profile().fonts.value(), fontDPI()),
-                                            _session->terminal().colorPalette(),
-                                            newSession->config().textureAtlasHashtableSlots.value(),
-                                            newSession->config().textureAtlasTileCount.value(),
-                                            newSession->config().textureAtlasDirectMapping.value(),
-                                            newSession->profile().hyperlinkDecorationNormal.value(),
-                                            newSession->profile().hyperlinkDecorationHover.value()
-                                            // TODO: , WindowMargin(windowMargin_.left, windowMargin_.bottom);
+    if (!_renderer)
+    {
+
+        _renderer = make_unique<vtrasterizer::Renderer>(
+            _session->profile().terminalSize.value(),
+            sanitizeFontDescription(profile().fonts.value(), fontDPI()),
+            _session->terminal().colorPalette(),
+            _session->config().renderer.value().textureAtlasHashtableSlots,
+            _session->config().renderer.value().textureAtlasTileCount,
+            _session->config().renderer.value().textureAtlasDirectMapping,
+            _session->profile().hyperlinkDecoration.value().normal,
+            _session->profile().hyperlinkDecoration.value().hover
+            // TODO: , WindowMargin(windowMargin_.left, windowMargin_.bottom);
         );
 
-    applyFontDPI();
-    updateImplicitSize();
-    updateMinimumSize();
+        // setup once with the renderer creation
+        applyFontDPI();
+        updateImplicitSize();
+        updateMinimumSize();
+    }
 
     _session->attachDisplay(*this); // NB: Requires Renderer to be instanciated to retrieve grid metrics.
 
@@ -324,13 +349,15 @@ void TerminalDisplay::sizeChanged()
     if (!_session || !_renderTarget)
         return;
 
-    displayLog()(
-        "size changed to: {}x{} (session {})", width(), height(), _session ? "available" : "not attached");
+    if (width() == 0.0 || height() == 0.0)
+        // This can happen when the window is minimized, or when the window is not yet fully initialized.
+        return;
 
-    auto const qtBaseDisplaySize =
-        vtbackend::ImageSize { Width::cast_from(width()), Height::cast_from(height()) };
-    auto const actualPixelSize = qtBaseDisplaySize * contentScale();
-    displayLog()("Resizing view to {}x{} virtual ({} actual).", width(), height(), actualPixelSize);
+    displayLog()("Size changed to {}x{} virtual", width(), height());
+
+    auto const virtualSize = vtbackend::ImageSize { Width::cast_from(width()), Height::cast_from(height()) };
+    auto const actualPixelSize = virtualSize * contentScale();
+    displayLog()("Resizing view to {} virtual ({} actual).", virtualSize, actualPixelSize);
     applyResize(actualPixelSize, *_session, *_renderer);
 }
 
@@ -424,7 +451,10 @@ void TerminalDisplay::applyFontDPI()
     if (newFontDPI == _lastFontDPI)
         return;
 
-    displayLog()("Applying DPI {}.", newFontDPI);
+    displayLog()("Applying DPI {} (via content scale {}, {}).",
+                 newFontDPI,
+                 contentScale(),
+                 window() ? "Window present" : "No window");
     _lastFontDPI = newFontDPI;
 
     // logDisplayInfo();
@@ -436,9 +466,7 @@ void TerminalDisplay::applyFontDPI()
 
     auto fd = _renderer->fontDescriptions();
     fd.dpi = newFontDPI;
-    _renderer->setFonts(fd);
-
-    _session->setContentScale(contentScale());
+    _renderer->setFonts(std::move(fd));
 
     if (!_renderTarget)
         return;
@@ -506,7 +534,7 @@ void TerminalDisplay::onDpiConfigChanged()
 
 void TerminalDisplay::onSceneGrapheInitialized()
 {
-    // displayLog()("onSceneGrapheInitialized");
+    displayLog()("onSceneGrapheInitialized ({}x{}, DPR {})", width(), height(), contentScale());
 
 #if !defined(NDEBUG) && defined(GL_DEBUG_OUTPUT) && defined(CONTOUR_DEBUG_OPENGL)
     CHECKED_GL(glEnable(GL_DEBUG_OUTPUT));
@@ -519,16 +547,17 @@ void TerminalDisplay::onBeforeSynchronize()
     if (!_session)
         return;
 
-    // find screen with biggest width
-    auto* screenToUse = window()->screen();
-    for (auto* screen: window()->screen()->virtualSiblings())
+    if (width() < 1.0 || height() < 1.0)
+        // e.g. this can happen when the window is not yet fully initialized
+        return;
+
+    window()->setScreen(findScreenWithBiggestWidth(window()->screen()));
+
+    if (_sessionChanged)
     {
-        if (screen->size().width() > screenToUse->size().width())
-        {
-            screenToUse = screen;
-        }
+        _sessionChanged = false;
+        createRenderer();
     }
-    window()->setScreen(screenToUse);
 
     if (!_renderTarget)
     {
@@ -543,7 +572,6 @@ void TerminalDisplay::onBeforeSynchronize()
 
     auto const dpr = contentScale();
     auto const windowSize = window()->size() * dpr;
-    Require(width() > 1.0 && height() > 1.0);
 
     auto const viewSize =
         ImageSize { Width::cast_from(windowSize.width()), Height::cast_from(windowSize.height()) };
@@ -558,8 +586,8 @@ void TerminalDisplay::onBeforeSynchronize()
 void TerminalDisplay::createRenderer()
 {
     Require(!_renderTarget);
-    Require(_session);
     Require(_renderer);
+    Require(_session);
     Require(window());
 
     auto const textureTileSize = gridMetrics().cellSize;
@@ -622,16 +650,7 @@ void TerminalDisplay::createRenderer()
 
     _session->configureDisplay();
 
-    // {{{ Apply proper grid/pixel sizes to terminal
-    {
-        auto const qtBaseDisplaySize =
-            ImageSize { vtbackend::Width::cast_from(width()), vtbackend::Height::cast_from(height()) };
-
-        auto const actualDisplaySize = qtBaseDisplaySize * contentScale();
-
-        applyResize(actualDisplaySize, *_session, *_renderer);
-    }
-    // }}}
+    resizeTerminalToDisplaySize();
 
     displayLog()("Implicit size: {}x{}", implicitWidth(), implicitHeight());
 }
@@ -725,6 +744,20 @@ void TerminalDisplay::onAfterRendering()
     // We use this to schedule the next rendering frame, if needed.
     // This signal is emitted from the scene graph rendering thread
     paint();
+    if (_saveScreenshot)
+    {
+        std::visit(crispy::overloaded { [&](const std::filesystem::path& path) {
+                                           screenshot().save(QString::fromStdString(path.string()));
+                                       },
+                                        [&](std::monostate) {
+                                            if (QClipboard* clipboard = QGuiApplication::clipboard();
+                                                clipboard != nullptr)
+                                                clipboard->setImage(screenshot(), QClipboard::Clipboard);
+                                        } },
+                   _saveScreenshot.value());
+
+        _saveScreenshot = std::nullopt;
+    }
 
     if (!_state.finish())
     {
@@ -824,17 +857,20 @@ void TerminalDisplay::inputMethodEvent(QInputMethodEvent* event)
 
 QVariant TerminalDisplay::inputMethodQuery(Qt::InputMethodQuery query) const
 {
-    QPoint cursorPos = QPoint();
-    auto const dpr = contentScale();
-    if (terminal().isCursorInViewport())
-    {
-        auto const gridCursorPos = terminal().currentScreen().cursor().position;
-        cursorPos.setX(int(unbox<double>(gridCursorPos.column)
-                           * unbox<double>(_renderer->gridMetrics().cellSize.width)));
-        cursorPos.setY(
-            int(unbox<double>(gridCursorPos.line) * unbox<double>(_renderer->gridMetrics().cellSize.height)));
-        cursorPos /= dpr;
-    }
+    auto const getCursorPosition = [&]() -> QPoint {
+        QPoint cursorPos = QPoint();
+        if (terminal().isCursorInViewport())
+        {
+            auto const dpr = contentScale();
+            auto const gridCursorPos = terminal().currentScreen().cursor().position;
+            cursorPos.setX(int(unbox<double>(gridCursorPos.column)
+                               * unbox<double>(_renderer->gridMetrics().cellSize.width)));
+            cursorPos.setY(int(unbox<double>(gridCursorPos.line)
+                               * unbox<double>(_renderer->gridMetrics().cellSize.height)));
+            cursorPos /= dpr;
+        }
+        return cursorPos;
+    };
 
     switch (query)
     {
@@ -842,6 +878,8 @@ QVariant TerminalDisplay::inputMethodQuery(Qt::InputMethodQuery query) const
             auto const& gridMetrics = _renderer->gridMetrics();
             auto theContentsRect = QRect(); // TODO: contentsRect();
             auto result = QRect();
+            auto const dpr = contentScale();
+            auto const cursorPos = getCursorPosition();
             result.setLeft(theContentsRect.left() + cursorPos.x());
             result.setTop(theContentsRect.top() + cursorPos.y());
             result.setWidth(int(unbox<double>(gridMetrics.cellSize.width)
@@ -851,13 +889,15 @@ QVariant TerminalDisplay::inputMethodQuery(Qt::InputMethodQuery query) const
             break;
         }
         // TODO?: case Qt::ImCursorRectangle:
-        // case Qt::ImMicroFocus:
+        // case Qt::ImMicroFocus: {
+        //     auto const cursorPos = getCursorPosition();
         //     return imageToDisplay(QRect(cursorPos.x(), cursorPos.y(), 1, 1));
+        // }
         // case Qt::ImFont:
         //     return QFont("monospace", 10);
         case Qt::ImCursorPosition:
             // return the cursor position within the current line
-            return cursorPos.x();
+            return getCursorPosition().x();
         case Qt::ImSurroundingText:
             // return the text from the current line
             if (terminal().isCursorInViewport())
@@ -973,9 +1013,23 @@ void TerminalDisplay::updateImplicitSize()
     assert(_session);
     assert(window());
 
-    auto const requiredSize = computeRequiredSize(_session->profile().margins.value(),
-                                                  _renderer->cellSize() * (1.0 / contentScale()),
-                                                  _session->terminal().totalPageSize());
+    auto const totalPageSize = _session->terminal().pageSize() + _session->terminal().statusLineHeight();
+    auto const dpr = contentScale(); // DPR = Device Pixel Ratio
+
+    auto const actualGridCellSize = _renderer->cellSize();
+    auto const actualToVirtualFactor = 1.0 / dpr;
+
+    auto const virtualMargins = _session->profile().margins.value();
+    auto const virtualCellSize = actualGridCellSize * actualToVirtualFactor;
+
+    auto const requiredSize = computeRequiredSize(virtualMargins, virtualCellSize, totalPageSize);
+
+    displayLog()("Implicit display size set to {} (margins: {}, cellSize: {}, contentScale: {}, pageSize: {}",
+                 requiredSize,
+                 virtualMargins,
+                 virtualCellSize,
+                 dpr,
+                 totalPageSize);
 
     setImplicitWidth(unbox<qreal>(requiredSize.width));
     setImplicitHeight(unbox<qreal>(requiredSize.height));
@@ -1009,7 +1063,7 @@ vtbackend::RefreshRate TerminalDisplay::refreshRate() const
 
 DPI TerminalDisplay::fontDPI() const noexcept
 {
-    return DPI { 96, 96 } * contentScale();
+    return DPI { .x = 96, .y = 96 } * contentScale();
 }
 
 bool TerminalDisplay::isFullScreen() const
@@ -1020,7 +1074,11 @@ bool TerminalDisplay::isFullScreen() const
 vtbackend::ImageSize TerminalDisplay::pixelSize() const
 {
     assert(_session);
-    return gridMetrics().cellSize * _session->terminal().pageSize();
+    auto const scaledWindowMargins = applyContentScale(_session->profile().margins.value(), contentScale());
+    auto const scaledWindowMarginsPixels =
+        vtbackend::ImageSize { Width::cast_from(unbox(scaledWindowMargins.horizontal) * 2),
+                               Height::cast_from(unbox(scaledWindowMargins.vertical) * 2) };
+    return gridMetrics().cellSize * _session->terminal().pageSize() + scaledWindowMarginsPixels;
 }
 
 vtbackend::ImageSize TerminalDisplay::cellSize() const
@@ -1060,6 +1118,18 @@ void TerminalDisplay::doDumpState()
     _doDumpState = true;
 }
 
+QImage TerminalDisplay::screenshot()
+{
+    _renderer->render(terminal(), _renderingPressure);
+    auto [size, image] = _renderTarget->takeScreenshot();
+
+    return QImage(image.data(),
+                  size.width.as<int>(),
+                  size.height.as<int>(),
+                  QImage::Format_RGBA8888_Premultiplied)
+        .mirrored(false, true);
+}
+
 void TerminalDisplay::doDumpStateInternal()
 {
 
@@ -1146,10 +1216,7 @@ void TerminalDisplay::doDumpStateInternal()
 
     auto screenshotFilePath = targetDir / "screenshot.png";
     displayLog()("Saving screenshot to: {}", screenshotFilePath.generic_string());
-    auto [size, image] = _renderTarget->takeScreenshot();
-    QImage(image.data(), size.width.as<int>(), size.height.as<int>(), QImage::Format_RGBA8888_Premultiplied)
-        .mirrored(false, true)
-        .save(QString::fromStdString(screenshotFilePath.string()));
+    screenshot().save(QString::fromStdString(screenshotFilePath.string()));
 }
 
 void TerminalDisplay::notify(std::string_view /*_title*/, std::string_view /*_body*/)
@@ -1157,15 +1224,15 @@ void TerminalDisplay::notify(std::string_view /*_title*/, std::string_view /*_bo
     // TODO: showNotification callback to Controller?
 }
 
-void TerminalDisplay::adaptToWidgetSize()
+void TerminalDisplay::resizeTerminalToDisplaySize()
 {
     // Resize widget (same pixels, but adjusted terminal rows/columns and margin)
     Require(_renderer != nullptr);
     Require(_session != nullptr);
 
-    auto const qtBaseDisplaySize =
+    auto const virtualDisplaySize =
         ImageSize { vtbackend::Width::cast_from(width()), vtbackend::Height::cast_from(height()) };
-    auto const actualDisplaySize = qtBaseDisplaySize * contentScale();
+    auto const actualDisplaySize = virtualDisplaySize * contentScale();
     applyResize(actualDisplaySize, *_session, *_renderer);
 }
 
@@ -1228,7 +1295,7 @@ bool TerminalDisplay::setFontSize(text::font_size newFontSize)
     if (!_renderer->setFontSize(newFontSize))
         return false;
 
-    adaptToWidgetSize();
+    resizeTerminalToDisplaySize();
     updateMinimumSize();
     // logDisplayInfo();
     return true;
