@@ -56,12 +56,13 @@ ColorPalette::Palette const ColorPalette::defaultColorPalette = []() constexpr {
         for (unsigned green = 0; green < 6; ++green)
             for (unsigned blue = 0; blue < 6; ++blue)
                 colors[16 + (red * 36) + (green * 6) + blue] =
-                    RGBColor { static_cast<uint8_t>(red ? (red * 40 + 55) : 0),
-                               static_cast<uint8_t>(green ? (green * 40 + 55) : 0),
-                               static_cast<uint8_t>(blue ? (blue * 40 + 55) : 0) };
+                    RGBColor { static_cast<uint8_t>(red ? ((red * 40) + 55) : 0),
+                               static_cast<uint8_t>(green ? ((green * 40) + 55) : 0),
+                               static_cast<uint8_t>(blue ? ((blue * 40) + 55) : 0) };
 
     // colors 232-255 are a grayscale ramp, intentionally leaving out black and white
-    for (uint8_t gray = 0, level = uint8_t(gray * 10 + 8); gray < 24; ++gray, level = uint8_t(gray * 10 + 8))
+    for (uint8_t gray = 0, level = uint8_t((gray * 10) + 8); gray < 24;
+         ++gray, level = uint8_t((gray * 10) + 8))
         colors[size_t(232 + gray)] = RGBColor { level, level, level };
 
     // dim colors
