@@ -7,12 +7,11 @@
 #include <crispy/escape.h>
 #include <crispy/sort.h>
 
-#include <fmt/format.h>
-
 #include <gsl/pointers>
 #include <gsl/span>
 
 #include <array>
+#include <format>
 #include <optional>
 #include <string>
 
@@ -31,12 +30,12 @@ enum class FunctionCategory : uint8_t
 // VT sequence documentation in markdown format
 struct FunctionDocumentation
 {
-    std::string_view mnemonic;
-    std::string_view comment;
-    std::string_view parameters;
-    std::string_view description;
-    std::string_view notes;
-    std::string_view examples;
+    std::string_view mnemonic {};
+    std::string_view comment {};
+    std::string_view parameters {};
+    std::string_view description {};
+    std::string_view notes {};
+    std::string_view examples {};
 };
 
 // {{{ documentation
@@ -117,6 +116,8 @@ constexpr inline auto WINMANIP = FunctionDocumentation { .mnemonic = "WINMANIP",
 constexpr inline auto XTCAPTURE = FunctionDocumentation { .mnemonic = "XTCAPTURE", .comment = "Report screen buffer capture." };
 constexpr inline auto XTPOPCOLORS = FunctionDocumentation { .mnemonic = "XTPOPCOLORS", .comment = "Pops the color palette from the palette's saved-stack." };
 constexpr inline auto XTPUSHCOLORS = FunctionDocumentation { .mnemonic = "XTPUSHCOLORS", .comment = "Pushes the color palette onto the palette's saved-stack." };
+constexpr inline auto SGRRESTORE = FunctionDocumentation { .mnemonic = "SGRRESTORE", .comment = "Restores video attributes." };
+constexpr inline auto SGRSAVE = FunctionDocumentation { .mnemonic = "SGRSAVE", .comment = "Saves video attributes onto stack." };
 constexpr inline auto XTREPORTCOLORS = FunctionDocumentation { .mnemonic = "XTREPORTCOLORS", .comment = "Reports number of color palettes on the stack." };
 constexpr inline auto XTRESTORE = FunctionDocumentation { .mnemonic = "XTRESTORE", .comment = "Restore DEC private modes." };
 constexpr inline auto XTSAVE = FunctionDocumentation { .mnemonic = "XTSAVE", .comment = "Save DEC private modes." };
@@ -164,7 +165,7 @@ constexpr inline auto SETXPROP = FunctionDocumentation { .mnemonic = "SETXPROP",
 // }}}
 
 /// Defines a function with all its syntax requirements plus some additional meta information.
-struct FunctionDefinition // TODO: rename Function
+struct Function
 {
     FunctionCategory category;  // (3 bits) C0, ESC, CSI, OSC, DCS
     char leader;                // (3 bits) 0x3C..0x3F (one of: < = > ?, or 0x00 for none)
@@ -201,7 +202,7 @@ struct FunctionDefinition // TODO: rename Function
         if constexpr (sizeof...(Args) > 0)
         {
             result.reserve(sizeof...(Args) * 4);
-            ((result += fmt::format("{};", std::forward<Args>(parameters))), ...);
+            ((result += std::format("{};", std::forward<Args>(parameters))), ...);
             result.pop_back(); // remove trailing ';'
         }
         if (intermediate)
@@ -246,7 +247,7 @@ struct FunctionDefinition // TODO: rename Function
     constexpr operator id_type() const noexcept { return id(); }
 };
 
-constexpr int compare(FunctionDefinition const& a, FunctionDefinition const& b)
+constexpr int compare(Function const& a, Function const& b)
 {
     if (a.category != b.category)
         return static_cast<int>(a.category) - static_cast<int>(b.category);
@@ -267,12 +268,12 @@ constexpr int compare(FunctionDefinition const& a, FunctionDefinition const& b)
 }
 
 // clang-format off
-constexpr bool operator==(FunctionDefinition const& a, FunctionDefinition const& b) noexcept { return compare(a, b) == 0; }
-constexpr bool operator!=(FunctionDefinition const& a, FunctionDefinition const& b) noexcept { return compare(a, b) != 0; }
-constexpr bool operator<=(FunctionDefinition const& a, FunctionDefinition const& b) noexcept { return compare(a, b) <= 0; }
-constexpr bool operator>=(FunctionDefinition const& a, FunctionDefinition const& b) noexcept { return compare(a, b) >= 0; }
-constexpr bool operator<(FunctionDefinition const& a, FunctionDefinition const& b) noexcept { return compare(a, b) < 0; }
-constexpr bool operator>(FunctionDefinition const& a, FunctionDefinition const& b) noexcept { return compare(a, b) > 0; }
+constexpr bool operator==(Function const& a, Function const& b) noexcept { return compare(a, b) == 0; }
+constexpr bool operator!=(Function const& a, Function const& b) noexcept { return compare(a, b) != 0; }
+constexpr bool operator<=(Function const& a, Function const& b) noexcept { return compare(a, b) <= 0; }
+constexpr bool operator>=(Function const& a, Function const& b) noexcept { return compare(a, b) >= 0; }
+constexpr bool operator<(Function const& a, Function const& b) noexcept { return compare(a, b) < 0; }
+constexpr bool operator>(Function const& a, Function const& b) noexcept { return compare(a, b) > 0; }
 // clang-format on
 
 struct FunctionSelector
@@ -289,7 +290,7 @@ struct FunctionSelector
     char finalSymbol;
 };
 
-constexpr int compare(FunctionSelector const& a, FunctionDefinition const& b) noexcept
+constexpr int compare(FunctionSelector const& a, Function const& b) noexcept
 {
     if (a.category != b.category)
         return static_cast<int>(a.category) - static_cast<int>(b.category);
@@ -322,29 +323,29 @@ namespace detail // {{{
                       std::string_view comment,
                       VTType vt = VTType::VT100) noexcept
     {
-        return FunctionDefinition { .category = FunctionCategory::C0,
-                                    .leader = 0,
-                                    .intermediate = 0,
-                                    .finalSymbol = finalCharacter,
-                                    .minimumParameters = 0,
-                                    .maximumParameters = 0,
-                                    .conformanceLevel = vt,
-                                    .extension = VTExtension::None,
-                                    .documentation =
-                                        FunctionDocumentation { .mnemonic = mnemonic, .comment = comment } };
+        return Function { .category = FunctionCategory::C0,
+                          .leader = 0,
+                          .intermediate = 0,
+                          .finalSymbol = finalCharacter,
+                          .minimumParameters = 0,
+                          .maximumParameters = 0,
+                          .conformanceLevel = vt,
+                          .extension = VTExtension::None,
+                          .documentation =
+                              FunctionDocumentation { .mnemonic = mnemonic, .comment = comment } };
     }
 
     constexpr auto OSC(uint16_t code, VTExtension ext, FunctionDocumentation documentation) noexcept
     {
-        return FunctionDefinition { .category = FunctionCategory::OSC,
-                                    .leader = 0,
-                                    .intermediate = 0,
-                                    .finalSymbol = 0,
-                                    .minimumParameters = 0,
-                                    .maximumParameters = code,
-                                    .conformanceLevel = VTType::VT100,
-                                    .extension = ext,
-                                    .documentation = documentation };
+        return Function { .category = FunctionCategory::OSC,
+                          .leader = 0,
+                          .intermediate = 0,
+                          .finalSymbol = 0,
+                          .minimumParameters = 0,
+                          .maximumParameters = code,
+                          .conformanceLevel = VTType::VT100,
+                          .extension = ext,
+                          .documentation = documentation };
     }
 
     constexpr auto ESC(std::optional<char> intermediate,
@@ -352,15 +353,15 @@ namespace detail // {{{
                        VTType vt,
                        FunctionDocumentation documentation) noexcept
     {
-        return FunctionDefinition { .category = FunctionCategory::ESC,
-                                    .leader = 0,
-                                    .intermediate = intermediate.value_or(0),
-                                    .finalSymbol = finalCharacter,
-                                    .minimumParameters = 0,
-                                    .maximumParameters = 0,
-                                    .conformanceLevel = vt,
-                                    .extension = VTExtension::None,
-                                    .documentation = documentation };
+        return Function { .category = FunctionCategory::ESC,
+                          .leader = 0,
+                          .intermediate = intermediate.value_or(0),
+                          .finalSymbol = finalCharacter,
+                          .minimumParameters = 0,
+                          .maximumParameters = 0,
+                          .conformanceLevel = vt,
+                          .extension = VTExtension::None,
+                          .documentation = documentation };
     }
 
     constexpr auto CSI(std::optional<char> leader,
@@ -372,15 +373,15 @@ namespace detail // {{{
                        FunctionDocumentation documentation) noexcept
     {
         // TODO: static_assert on leader/intermediate range-or-null
-        return FunctionDefinition { .category = FunctionCategory::CSI,
-                                    .leader = leader.value_or(0),
-                                    .intermediate = intermediate.value_or(0),
-                                    .finalSymbol = finalCharacter,
-                                    .minimumParameters = argc0,
-                                    .maximumParameters = argc1,
-                                    .conformanceLevel = vt,
-                                    .extension = VTExtension::None,
-                                    .documentation = documentation };
+        return Function { .category = FunctionCategory::CSI,
+                          .leader = leader.value_or(0),
+                          .intermediate = intermediate.value_or(0),
+                          .finalSymbol = finalCharacter,
+                          .minimumParameters = argc0,
+                          .maximumParameters = argc1,
+                          .conformanceLevel = vt,
+                          .extension = VTExtension::None,
+                          .documentation = documentation };
     }
 
     constexpr auto CSI(std::optional<char> leader,
@@ -392,15 +393,15 @@ namespace detail // {{{
                        FunctionDocumentation documentation) noexcept
     {
         // TODO: static_assert on leader/intermediate range-or-null
-        return FunctionDefinition { .category = FunctionCategory::CSI,
-                                    .leader = leader.value_or(0),
-                                    .intermediate = intermediate.value_or(0),
-                                    .finalSymbol = finalCharacter,
-                                    .minimumParameters = argc0,
-                                    .maximumParameters = argc1,
-                                    .conformanceLevel = VTType::VT100,
-                                    .extension = ext,
-                                    .documentation = documentation };
+        return Function { .category = FunctionCategory::CSI,
+                          .leader = leader.value_or(0),
+                          .intermediate = intermediate.value_or(0),
+                          .finalSymbol = finalCharacter,
+                          .minimumParameters = argc0,
+                          .maximumParameters = argc1,
+                          .conformanceLevel = VTType::VT100,
+                          .extension = ext,
+                          .documentation = documentation };
     }
 
     constexpr auto DCS(std::optional<char> leader,
@@ -412,15 +413,15 @@ namespace detail // {{{
                        FunctionDocumentation documentation) noexcept
     {
         // TODO: static_assert on leader/intermediate range-or-null
-        return FunctionDefinition { .category = FunctionCategory::DCS,
-                                    .leader = leader.value_or(0),
-                                    .intermediate = intermediate.value_or(0),
-                                    .finalSymbol = finalCharacter,
-                                    .minimumParameters = argc0,
-                                    .maximumParameters = argc1,
-                                    .conformanceLevel = vt,
-                                    .extension = VTExtension::None,
-                                    .documentation = documentation };
+        return Function { .category = FunctionCategory::DCS,
+                          .leader = leader.value_or(0),
+                          .intermediate = intermediate.value_or(0),
+                          .finalSymbol = finalCharacter,
+                          .minimumParameters = argc0,
+                          .maximumParameters = argc1,
+                          .conformanceLevel = vt,
+                          .extension = VTExtension::None,
+                          .documentation = documentation };
     }
 
     constexpr auto DCS(std::optional<char> leader,
@@ -432,15 +433,15 @@ namespace detail // {{{
                        FunctionDocumentation documentation) noexcept
     {
         // TODO: static_assert on leader/intermediate range-or-null
-        return FunctionDefinition { .category = FunctionCategory::DCS,
-                                    .leader = leader.value_or(0),
-                                    .intermediate = intermediate.value_or(0),
-                                    .finalSymbol = finalCharacter,
-                                    .minimumParameters = argc0,
-                                    .maximumParameters = argc1,
-                                    .conformanceLevel = VTType::VT100,
-                                    .extension = ext,
-                                    .documentation = documentation };
+        return Function { .category = FunctionCategory::DCS,
+                          .leader = leader.value_or(0),
+                          .intermediate = intermediate.value_or(0),
+                          .finalSymbol = finalCharacter,
+                          .minimumParameters = argc0,
+                          .maximumParameters = argc1,
+                          .conformanceLevel = VTType::VT100,
+                          .extension = ext,
+                          .documentation = documentation };
     }
 } // namespace detail
 // }}}
@@ -578,6 +579,8 @@ constexpr inline auto WINMANIP    = detail::CSI(std::nullopt, 1, 3, std::nullopt
 constexpr inline auto XTCAPTURE   = detail::CSI('>', 0, 2, std::nullopt, 't', VTExtension::Contour, documentation::XTCAPTURE);
 constexpr inline auto XTPOPCOLORS    = detail::CSI(std::nullopt, 0, ArgsMax, '#', 'Q', VTExtension::XTerm, documentation::XTPOPCOLORS);
 constexpr inline auto XTPUSHCOLORS   = detail::CSI(std::nullopt, 0, ArgsMax, '#', 'P', VTExtension::XTerm, documentation::XTPUSHCOLORS);
+constexpr inline auto SGRRESTORE  = detail::CSI(std::nullopt, 0, 0, '#', '}', VTExtension::XTerm, documentation:: SGRRESTORE);
+constexpr inline auto SGRSAVE     = detail::CSI(std::nullopt, 0, 0, '#', '{', VTExtension::XTerm, documentation::SGRSAVE);
 constexpr inline auto XTREPORTCOLORS = detail::CSI(std::nullopt, 0, 0, '#', 'R', VTExtension::XTerm, documentation::XTREPORTCOLORS);
 constexpr inline auto XTRESTORE   = detail::CSI('?', 0, ArgsMax, std::nullopt, 'r', VTExtension::XTerm, documentation::XTRESTORE);
 constexpr inline auto XTSAVE      = detail::CSI('?', 0, ArgsMax, std::nullopt, 's', VTExtension::XTerm, documentation::XTSAVE);
@@ -726,6 +729,8 @@ constexpr static auto allFunctionsArray() noexcept
         SD,
         SETMARK,
         SGR,
+        SGRRESTORE,
+        SGRSAVE,
         SM,
         SU,
         TBC,
@@ -779,9 +784,7 @@ inline auto allFunctions() noexcept
 {
     static auto const funcs = []() constexpr {
         auto funcs = allFunctionsArray();
-        crispy::sort(funcs, [](FunctionDefinition const& a, FunctionDefinition const& b) constexpr {
-            return compare(a, b);
-        });
+        crispy::sort(funcs, [](Function const& a, Function const& b) constexpr { return compare(a, b); });
         return funcs;
     }();
 
@@ -805,33 +808,32 @@ class SupportedSequences
     [[nodiscard]] constexpr auto cend() const noexcept { return cbegin() + _lastIndex; }
 
   public:
-    [[nodiscard]] constexpr gsl::span<FunctionDefinition const> allSequences() const noexcept
+    [[nodiscard]] constexpr gsl::span<Function const> allSequences() const noexcept
     {
-        return gsl::span<FunctionDefinition const>(cbegin(), _supportedSequences.size());
+        return gsl::span<Function const>(cbegin(), _supportedSequences.size());
     }
 
-    [[nodiscard]] constexpr gsl::span<FunctionDefinition const> activeSequences() const noexcept
+    [[nodiscard]] constexpr gsl::span<Function const> activeSequences() const noexcept
     {
-        return gsl::span<FunctionDefinition const>(cbegin(), _lastIndex);
+        return gsl::span<Function const>(cbegin(), _lastIndex);
     }
 
     CRISPY_CONSTEXPR void reset(VTType vt) noexcept
     {
         // Partition the array such that first half contains all sequences with VTType less than or
         // equal to given VTTYpe.
-        auto* itr = std::partition(
-            begin(),
-            _supportedSequences.data() + _supportedSequences.size(),
-            [vt](const FunctionDefinition& value) noexcept { return value.conformanceLevel <= vt; });
+        auto* itr =
+            std::partition(begin(),
+                           _supportedSequences.data() + _supportedSequences.size(),
+                           [vt](const Function& value) noexcept { return value.conformanceLevel <= vt; });
 
         _lastIndex = std::distance(begin(), itr);
-        gsl::span<FunctionDefinition> availableDefinition(begin(), _lastIndex);
-        crispy::sort(
-            availableDefinition,
-            [](FunctionDefinition const& a, FunctionDefinition const& b) constexpr { return compare(a, b); });
+        gsl::span<Function> availableDefinition(begin(), _lastIndex);
+        crispy::sort(availableDefinition,
+                     [](Function const& a, Function const& b) constexpr { return compare(a, b); });
     }
 
-    CRISPY_CONSTEXPR void disableSequence(FunctionDefinition seq) noexcept
+    CRISPY_CONSTEXPR void disableSequence(Function seq) noexcept
     {
         auto* seqIter = std::find(begin(), end(), seq);
         if (seqIter != end())
@@ -842,7 +844,7 @@ class SupportedSequences
         }
     }
 
-    CRISPY_CONSTEXPR void enableSequence(FunctionDefinition seq) noexcept
+    CRISPY_CONSTEXPR void enableSequence(Function seq) noexcept
     {
         auto* const endArray = _supportedSequences.data() + _supportedSequences.size();
         auto* seqIter = std::find(end(), endArray, seq);
@@ -851,23 +853,21 @@ class SupportedSequences
             // Maybe could be done better since rest of the data is sorted
             std::iter_swap(end(), seqIter);
             ++_lastIndex;
-            gsl::span<FunctionDefinition> arr(begin(), end());
-            crispy::sort(arr, [](FunctionDefinition const& a, FunctionDefinition const& b) constexpr {
-                return compare(a, b);
-            });
+            gsl::span<Function> arr(begin(), end());
+            crispy::sort(arr, [](Function const& a, Function const& b) constexpr { return compare(a, b); });
         }
     }
 
   private:
-    std::array<FunctionDefinition, allFunctionsArray().size()> _supportedSequences = allFunctions();
+    std::array<Function, allFunctionsArray().size()> _supportedSequences = allFunctions();
     size_t _lastIndex = allFunctions().size(); // No of total active sequences
 };
 
 /// Selects a FunctionDefinition based on a FunctionSelector.
 ///
 /// @return the matching FunctionDefinition or nullptr if none matched.
-FunctionDefinition const* select(FunctionSelector const& selector,
-                                 gsl::span<FunctionDefinition const> availableDefinition) noexcept;
+Function const* select(FunctionSelector const& selector,
+                       gsl::span<Function const> availableDefinition) noexcept;
 
 /// Selects a FunctionDefinition based on given input Escape sequence fields.
 ///
@@ -877,9 +877,9 @@ FunctionDefinition const* select(FunctionSelector const& selector,
 /// @notice multi-character intermediates are intentionally not supported.
 ///
 /// @return the matching FunctionDefinition or nullptr if none matched.
-inline FunctionDefinition const* selectEscape(char intermediate,
-                                              char finalCharacter,
-                                              gsl::span<FunctionDefinition const> availableDefinition)
+inline Function const* selectEscape(char intermediate,
+                                    char finalCharacter,
+                                    gsl::span<Function const> availableDefinition)
 {
     return select({ FunctionCategory::ESC, 0, 0, intermediate, finalCharacter }, availableDefinition);
 }
@@ -894,11 +894,11 @@ inline FunctionDefinition const* selectEscape(char intermediate,
 /// @notice multi-character intermediates are intentionally not supported.
 ///
 /// @return the matching FunctionDefinition or nullptr if none matched.
-inline FunctionDefinition const* selectControl(char leader,
-                                               int argc,
-                                               char intermediate,
-                                               char finalCharacter,
-                                               gsl::span<FunctionDefinition const> availableDefinition)
+inline Function const* selectControl(char leader,
+                                     int argc,
+                                     char intermediate,
+                                     char finalCharacter,
+                                     gsl::span<Function const> availableDefinition)
 {
     return select({ FunctionCategory::CSI, leader, argc, intermediate, finalCharacter }, availableDefinition);
 }
@@ -910,8 +910,7 @@ inline FunctionDefinition const* selectControl(char leader,
 /// @notice multi-character intermediates are intentionally not supported.
 ///
 /// @return the matching FunctionDefinition or nullptr if none matched.
-inline FunctionDefinition const* selectOSCommand(int id,
-                                                 gsl::span<FunctionDefinition const> availableDefinition)
+inline Function const* selectOSCommand(int id, gsl::span<Function const> availableDefinition)
 {
     return select({ FunctionCategory::OSC, 0, id, 0, 0 }, availableDefinition);
 }
@@ -919,20 +918,17 @@ inline FunctionDefinition const* selectOSCommand(int id,
 } // namespace vtbackend
 
 template <>
-struct std::hash<vtbackend::FunctionDefinition>
+struct std::hash<vtbackend::Function>
 {
     /// This is actually perfect hashing.
-    constexpr uint32_t operator()(vtbackend::FunctionDefinition const& fun) const noexcept
-    {
-        return fun.id();
-    }
+    constexpr uint32_t operator()(vtbackend::Function const& fun) const noexcept { return fun.id(); }
 };
 
 // {{{ fmtlib support
 template <>
-struct fmt::formatter<vtbackend::FunctionCategory>: fmt::formatter<std::string_view>
+struct std::formatter<vtbackend::FunctionCategory>: std::formatter<std::string_view>
 {
-    auto format(const vtbackend::FunctionCategory value, format_context& ctx) -> format_context::iterator
+    auto format(const vtbackend::FunctionCategory value, auto& ctx) const
     {
         using vtbackend::FunctionCategory;
         string_view name;
@@ -964,43 +960,43 @@ struct fmt::formatter<vtbackend::FunctionCategory>: fmt::formatter<std::string_v
 };
 
 template <>
-struct fmt::formatter<vtbackend::FunctionDefinition>: fmt::formatter<std::string>
+struct std::formatter<vtbackend::Function>: std::formatter<std::string>
 {
-    auto format(const vtbackend::FunctionDefinition f, format_context& ctx) -> format_context::iterator
+    auto format(const vtbackend::Function f, auto& ctx) const
     {
         std::string value;
         switch (f.category)
         {
             case vtbackend::FunctionCategory::C0:
-                value = fmt::format("{}", crispy::escape(static_cast<uint8_t>(f.finalSymbol)));
+                value = std::format("{}", crispy::escape(static_cast<uint8_t>(f.finalSymbol)));
                 break;
             case vtbackend::FunctionCategory::ESC:
-                value = fmt::format("{} {} {}",
+                value = std::format("{} {} {}",
                                     f.category,
                                     f.intermediate ? f.intermediate : ' ',
                                     f.finalSymbol ? f.finalSymbol : ' ');
                 break;
             case vtbackend::FunctionCategory::OSC:
-                value = fmt::format("{} {}", f.category, f.maximumParameters);
+                value = std::format("{} {}", f.category, f.maximumParameters);
                 break;
             case vtbackend::FunctionCategory::DCS:
             case vtbackend::FunctionCategory::CSI:
                 if (f.minimumParameters == f.maximumParameters)
-                    value = fmt::format("{} {} {}    {} {}",
+                    value = std::format("{} {} {}    {} {}",
                                         f.category,
                                         f.leader ? f.leader : ' ',
                                         f.minimumParameters,
                                         f.intermediate ? f.intermediate : ' ',
                                         f.finalSymbol);
                 else if (f.maximumParameters == vtbackend::ArgsMax)
-                    value = fmt::format("{} {} {}..  {} {}",
+                    value = std::format("{} {} {}..  {} {}",
                                         f.category,
                                         f.leader ? f.leader : ' ',
                                         f.minimumParameters,
                                         f.intermediate ? f.intermediate : ' ',
                                         f.finalSymbol);
                 else
-                    value = fmt::format("{} {} {}..{} {} {}",
+                    value = std::format("{} {} {}..{} {} {}",
                                         f.category,
                                         f.leader ? f.leader : ' ',
                                         f.minimumParameters,
@@ -1014,19 +1010,19 @@ struct fmt::formatter<vtbackend::FunctionDefinition>: fmt::formatter<std::string
 };
 
 template <>
-struct fmt::formatter<vtbackend::FunctionSelector>: fmt::formatter<std::string>
+struct std::formatter<vtbackend::FunctionSelector>: std::formatter<std::string>
 {
-    auto format(const vtbackend::FunctionSelector f, format_context& ctx) -> format_context::iterator
+    auto format(const vtbackend::FunctionSelector f, auto& ctx) const
     {
         std::string value;
         // clang-format off
         switch (f.category)
         {
             case vtbackend::FunctionCategory::OSC:
-                value = fmt::format("{} {}", f.category, f.argc);
+                value = std::format("{} {}", f.category, f.argc);
                 break;
             default:
-                value = fmt::format("{} {} {} {} {}",
+                value = std::format("{} {} {} {} {}",
                                     f.category,
                                     f.leader ? f.leader : ' ',
                                     f.argc,
