@@ -54,6 +54,12 @@ using Modifiers = crispy::flags<Modifier>;
 /// @returns CSI parameter for given function key modifier
 constexpr size_t makeVirtualTerminalParam(Modifiers modifier) noexcept
 {
+#if defined(__APPLE__)
+    // Use option key as a control modifier to use
+    // Ctrl-Left[Right]Arrow for word navigation.
+    if (modifier == Modifier::Alt)
+        return 1 + Modifier::Control;
+#endif
     return 1 + modifier.value();
 }
 
