@@ -1,6 +1,7 @@
 // SPDX-License-Identifier: Apache-2.0
 #include <vtbackend/Terminal.h>
 #include <vtbackend/ViCommands.h>
+#include <vtbackend/ViInputHandler.h>
 #include <vtbackend/logging.h>
 #include <vtbackend/primitives.h>
 
@@ -195,7 +196,11 @@ bool ViCommands::jumpToNextMatch(unsigned count)
 {
     for (unsigned i = 0; i < count; ++i)
         if (auto const nextPosition = _terminal->searchNextMatch(cursorPosition))
+        {
+            inputLog()("jumpToNextMatch");
+            _jumpHistory.add(nextPosition.value());
             moveCursorTo(nextPosition.value());
+        }
         else
             return false;
 
@@ -206,7 +211,11 @@ bool ViCommands::jumpToPreviousMatch(unsigned count)
 {
     for (unsigned i = 0; i < count; ++i)
         if (auto const nextPosition = _terminal->searchPrevMatch(cursorPosition))
+        {
+            inputLog()("jumpToPreviousMatch");
+            _jumpHistory.add(nextPosition.value());
             moveCursorTo(nextPosition.value());
+        }
         else
             return false;
 
@@ -308,11 +317,11 @@ void ViCommands::executeYank(ViMotion motion, unsigned count)
         case ViMotion::Selection: {
             assert(_terminal->selector());
             if (_lastMode == ViMode::VisualBlock)
-                _terminal->setHighlightRange(
-                    RectangularHighlight { _terminal->selector()->from(), _terminal->selector()->to() });
+                _terminal->setHighlightRange(RectangularHighlight { .from = _terminal->selector()->from(),
+                                                                    .to = _terminal->selector()->to() });
             else
-                _terminal->setHighlightRange(
-                    LinearHighlight { _terminal->selector()->from(), _terminal->selector()->to() });
+                _terminal->setHighlightRange(LinearHighlight { .from = _terminal->selector()->from(),
+                                                               .to = _terminal->selector()->to() });
             _terminal->copyToClipboard(_terminal->extractSelectionText());
             _terminal->inputHandler().setMode(ViMode::Normal);
             break;
@@ -321,7 +330,7 @@ void ViCommands::executeYank(ViMotion motion, unsigned count)
             auto const [from, to] = translateToCellRange(motion, count);
             // motion is inclusive but for yank we want to exclude the last cell which is the first cell of
             // the next word
-            executeYank(from, { to.line, to.column - 1 });
+            executeYank(from, { .line = to.line, .column = to.column - 1 });
         }
         break;
     }
@@ -345,7 +354,7 @@ std::string ViCommands::extractTextAndHighlightRange(CellLocation from, CellLoca
     auto text = _terminal->extractSelectionText();
 
     _terminal->clearSelection();
-    _terminal->setHighlightRange(LinearHighlight { from, to });
+    _terminal->setHighlightRange(LinearHighlight { .from = from, .to = to });
     _terminal->inputHandler().setMode(ViMode::Normal);
     _terminal->screenUpdated();
     return text;
@@ -368,11 +377,11 @@ void ViCommands::executeOpen(ViMotion motion, unsigned count)
         case ViMotion::Selection: {
             assert(_terminal->selector());
             if (_lastMode == ViMode::VisualBlock)
-                _terminal->setHighlightRange(
-                    RectangularHighlight { _terminal->selector()->from(), _terminal->selector()->to() });
+                _terminal->setHighlightRange(RectangularHighlight { .from = _terminal->selector()->from(),
+                                                                    .to = _terminal->selector()->to() });
             else
-                _terminal->setHighlightRange(
-                    LinearHighlight { _terminal->selector()->from(), _terminal->selector()->to() });
+                _terminal->setHighlightRange(LinearHighlight { .from = _terminal->selector()->from(),
+                                                               .to = _terminal->selector()->to() });
 
             _terminal->copyToClipboard(_terminal->extractSelectionText());
 
@@ -411,6 +420,8 @@ void ViCommands::execute(ViOperator op, ViMotion motion, unsigned count, char32_
                 _lastChar = lastChar;
             }
             executeYank(motion, count);
+            if (_terminal->settings().isInsertAfterYank)
+                _terminal->inputHandler().setMode(ViMode::Insert);
             break;
         case ViOperator::Paste:
             //.
@@ -477,7 +488,7 @@ void ViCommands::paste(unsigned count, bool stripped)
 CellLocation ViCommands::prev(CellLocation location) const noexcept
 {
     if (location.column.value > 0)
-        return { location.line, location.column - 1 };
+        return { .line = location.line, .column = location.column - 1 };
 
     auto const topLineOffset = _terminal->isPrimaryScreen()
                                    ? -boxed_cast<LineOffset>(_terminal->primaryScreen().historyLineCount())
@@ -498,7 +509,7 @@ CellLocation ViCommands::next(CellLocation location) const noexcept
     if (location.column < rightMargin)
     {
         auto const width = max(uint8_t { 1 }, _terminal->currentScreen().cellWidthAt(location));
-        return { location.line, location.column + ColumnOffset::cast_from(width) };
+        return { .line = location.line, .column = location.column + ColumnOffset::cast_from(width) };
     }
 
     if (location.line < boxed_cast<LineOffset>(_terminal->pageSize().lines - 1))
@@ -598,7 +609,7 @@ CellLocationRange ViCommands::expandMatchingPair(TextObjectScope scope, char lef
             b = prev(b);
     }
 
-    return { a, b };
+    return { .first = a, .second = b };
 }
 
 CellLocationRange ViCommands::translateToCellRange(TextObjectScope scope,
@@ -654,27 +665,28 @@ CellLocationRange ViCommands::translateToCellRange(TextObjectScope scope,
             break;
         }
     }
-    return { a, b };
+    return { .first = a, .second = b };
 }
 
-CellLocationRange ViCommands::translateToCellRange(ViMotion motion, unsigned count) const noexcept
+CellLocationRange ViCommands::translateToCellRange(ViMotion motion, unsigned count) noexcept
 {
     switch (motion)
     {
         case ViMotion::FullLine:
-            return { cursorPosition - cursorPosition.column,
-                     { cursorPosition.line, _terminal->pageSize().columns.as<ColumnOffset>() - 1 } };
+            return { .first = cursorPosition - cursorPosition.column,
+                     .second = { .line = cursorPosition.line,
+                                 .column = _terminal->pageSize().columns.as<ColumnOffset>() - 1 } };
         default:
             //.
-            return { cursorPosition, translateToCellLocation(motion, count) };
+            return { .first = cursorPosition, .second = translateToCellLocationAndRecord(motion, count) };
     }
 }
 
 CellLocation ViCommands::findBeginOfWordAt(CellLocation location, JumpOver jumpOver) const noexcept
 {
     auto const firstAddressableLocation =
-        CellLocation { -LineOffset::cast_from(_terminal->currentScreen().historyLineCount()),
-                       ColumnOffset(0) };
+        CellLocation { .line = -LineOffset::cast_from(_terminal->currentScreen().historyLineCount()),
+                       .column = ColumnOffset(0) };
 
     auto current = location;
     auto leftLocation = prev(current);
@@ -734,7 +746,7 @@ bool ViCommands::compareCellTextAt(CellLocation position, char32_t codepoint) co
 CellLocation ViCommands::globalCharUp(CellLocation location, char ch, unsigned count) const noexcept
 {
     auto const pageTop = -_terminal->currentScreen().historyLineCount().as<LineOffset>();
-    auto result = CellLocation { location.line, ColumnOffset(0) };
+    auto result = CellLocation { .line = location.line, .column = ColumnOffset(0) };
     while (count > 0)
     {
         if (location.column == ColumnOffset(0) && result.line > pageTop)
@@ -754,7 +766,7 @@ CellLocation ViCommands::globalCharUp(CellLocation location, char ch, unsigned c
 CellLocation ViCommands::globalCharDown(CellLocation location, char ch, unsigned count) const noexcept
 {
     auto const pageBottom = _terminal->pageSize().lines.as<LineOffset>() - 1;
-    auto result = CellLocation { location.line, ColumnOffset(0) };
+    auto result = CellLocation { .line = location.line, .column = ColumnOffset(0) };
     while (count > 0)
     {
         if (location.column == ColumnOffset(0) && result.line < pageBottom)
@@ -771,8 +783,14 @@ CellLocation ViCommands::globalCharDown(CellLocation location, char ch, unsigned
     return result;
 }
 
-CellLocation ViCommands::translateToCellLocation(ViMotion motion, unsigned count) const noexcept
+// NOLINTNEXTLINE(readability-function-cognitive-complexity)
+CellLocation ViCommands::translateToCellLocationAndRecord(ViMotion motion, unsigned count) noexcept
 {
+    auto addJumpHistory = [this](CellLocation const& location) {
+        inputLog()("addJumpHistory: {}:{}", location.line, location.column);
+        _jumpHistory.add(location);
+        return location;
+    };
     switch (motion)
     {
         case ViMotion::CharLeft: // h
@@ -796,62 +814,63 @@ CellLocation ViCommands::translateToCellLocation(ViMotion motion, unsigned count
             return resultPosition;
         }
         case ViMotion::ScreenColumn: // |
-            return snapToCell({ cursorPosition.line,
-                                min(ColumnOffset::cast_from(count - 1),
-                                    _terminal->pageSize().columns.as<ColumnOffset>() - 1) });
+            return snapToCell({ .line = cursorPosition.line,
+                                .column = min(ColumnOffset::cast_from(count - 1),
+                                              _terminal->pageSize().columns.as<ColumnOffset>() - 1) });
         case ViMotion::FileBegin: // gg
             return snapToCell(
-                { LineOffset::cast_from(-_terminal->currentScreen().historyLineCount().as<int>()),
-                  ColumnOffset(0) });
+                { .line = LineOffset::cast_from(-_terminal->currentScreen().historyLineCount().as<int>()),
+                  .column = ColumnOffset(0) });
         case ViMotion::FileEnd: // G
-            return snapToCell({ _terminal->pageSize().lines.as<LineOffset>() - 1, ColumnOffset(0) });
+            return addJumpHistory(snapToCell(
+                { .line = _terminal->pageSize().lines.as<LineOffset>() - 1, .column = ColumnOffset(0) }));
         case ViMotion::PageTop: // <S-H>
-            return snapToCell({ boxed_cast<LineOffset>(-_terminal->viewport().scrollOffset())
-                                    + *_terminal->viewport().scrollOff(),
-                                ColumnOffset(0) });
+            return snapToCell({ .line = boxed_cast<LineOffset>(-_terminal->viewport().scrollOffset())
+                                        + *_terminal->viewport().scrollOff(),
+                                .column = ColumnOffset(0) });
         case ViMotion::PageBottom: // <S-L>
-            return snapToCell({ boxed_cast<LineOffset>(-_terminal->viewport().scrollOffset())
-                                    + boxed_cast<LineOffset>(_terminal->pageSize().lines
-                                                             - *_terminal->viewport().scrollOff() - 1),
-                                ColumnOffset(0) });
+            return snapToCell({ .line = boxed_cast<LineOffset>(-_terminal->viewport().scrollOffset())
+                                        + boxed_cast<LineOffset>(_terminal->pageSize().lines
+                                                                 - *_terminal->viewport().scrollOff() - 1),
+                                .column = ColumnOffset(0) });
         case ViMotion::LineBegin: // 0
-            return { cursorPosition.line, ColumnOffset(0) };
+            return { .line = cursorPosition.line, .column = ColumnOffset(0) };
         case ViMotion::LineTextBegin: // ^
         {
-            auto result = CellLocation { cursorPosition.line, ColumnOffset(0) };
+            auto result = CellLocation { .line = cursorPosition.line, .column = ColumnOffset(0) };
             while (result.column < _terminal->pageSize().columns.as<ColumnOffset>() - 1
                    && _terminal->currentScreen().isCellEmpty(result))
                 ++result.column;
             return result;
         }
         case ViMotion::LineDown: // j
-            return { min(cursorPosition.line + LineOffset::cast_from(count),
-                         _terminal->pageSize().lines.as<LineOffset>() - 1),
-                     cursorPosition.column };
+            return { .line = min(cursorPosition.line + LineOffset::cast_from(count),
+                                 _terminal->pageSize().lines.as<LineOffset>() - 1),
+                     .column = cursorPosition.column };
         case ViMotion::LineEnd: // $
             return getRightMostNonEmptyCellLocation(*_terminal, cursorPosition.line);
         case ViMotion::LineUp: // k
-            return { max(cursorPosition.line - LineOffset::cast_from(count),
-                         -_terminal->currentScreen().historyLineCount().as<LineOffset>()),
-                     cursorPosition.column };
+            return { .line = max(cursorPosition.line - LineOffset::cast_from(count),
+                                 -_terminal->currentScreen().historyLineCount().as<LineOffset>()),
+                     .column = cursorPosition.column };
         case ViMotion::LinesCenter: // M
-            return { LineOffset::cast_from(_terminal->pageSize().lines / 2 - 1)
-                         - boxed_cast<LineOffset>(_terminal->viewport().scrollOffset()),
-                     cursorPosition.column };
+            return addJumpHistory({ .line = LineOffset::cast_from(_terminal->pageSize().lines / 2 - 1)
+                                            - boxed_cast<LineOffset>(_terminal->viewport().scrollOffset()),
+                                    .column = cursorPosition.column });
         case ViMotion::PageDown:
-            return { min(cursorPosition.line + LineOffset::cast_from(_terminal->pageSize().lines / 2),
-                         _terminal->pageSize().lines.as<LineOffset>() - 1),
-                     cursorPosition.column };
+            return { .line = min(cursorPosition.line + LineOffset::cast_from(_terminal->pageSize().lines / 2),
+                                 _terminal->pageSize().lines.as<LineOffset>() - 1),
+                     .column = cursorPosition.column };
         case ViMotion::PageUp:
-            return { max(cursorPosition.line - LineOffset::cast_from(_terminal->pageSize().lines / 2),
-                         -_terminal->currentScreen().historyLineCount().as<LineOffset>()),
-                     cursorPosition.column };
+            return { .line = max(cursorPosition.line - LineOffset::cast_from(_terminal->pageSize().lines / 2),
+                                 -_terminal->currentScreen().historyLineCount().as<LineOffset>()),
+                     .column = cursorPosition.column };
             return cursorPosition
                    - min(cursorPosition.line, LineOffset::cast_from(_terminal->pageSize().lines) / 2);
         case ViMotion::ParagraphBackward: // {
         {
             auto const pageTop = -_terminal->currentScreen().historyLineCount().as<LineOffset>();
-            auto prev = CellLocation { cursorPosition.line, ColumnOffset(0) };
+            auto prev = CellLocation { .line = cursorPosition.line, .column = ColumnOffset(0) };
             if (prev.line.value > 0)
                 prev.line--;
             auto current = prev;
@@ -862,20 +881,20 @@ CellLocation ViCommands::translateToCellLocation(ViMotion motion, unsigned count
                 prev.line = current.line;
                 current.line--;
             }
-            return snapToCell(current);
+            return addJumpHistory(snapToCell(current));
         }
         case ViMotion::GlobalCurlyOpenUp: // [[
-            return globalCharUp(cursorPosition, '{', count);
+            return addJumpHistory(globalCharUp(cursorPosition, '{', count));
         case ViMotion::GlobalCurlyOpenDown: // ]]
-            return globalCharDown(cursorPosition, '{', count);
+            return addJumpHistory(globalCharDown(cursorPosition, '{', count));
         case ViMotion::GlobalCurlyCloseUp: // []
-            return globalCharUp(cursorPosition, '}', count);
+            return addJumpHistory(globalCharUp(cursorPosition, '}', count));
         case ViMotion::GlobalCurlyCloseDown: // ][
-            return globalCharDown(cursorPosition, '}', count);
+            return addJumpHistory(globalCharDown(cursorPosition, '}', count));
         case ViMotion::LineMarkUp: // [m
         {
             auto const gridTop = -_terminal->currentScreen().historyLineCount().as<LineOffset>();
-            auto result = CellLocation { cursorPosition.line, ColumnOffset(0) };
+            auto result = CellLocation { .line = cursorPosition.line, .column = ColumnOffset(0) };
             while (count > 0)
             {
                 if (result.line > gridTop
@@ -886,12 +905,12 @@ CellLocation ViCommands::translateToCellLocation(ViMotion motion, unsigned count
                     --result.line;
                 --count;
             }
-            return result;
+            return addJumpHistory(result);
         }
         case ViMotion::LineMarkDown: // ]m
         {
             auto const pageBottom = _terminal->pageSize().lines.as<LineOffset>() - 1;
-            auto result = CellLocation { cursorPosition.line, ColumnOffset(0) };
+            auto result = CellLocation { .line = cursorPosition.line, .column = ColumnOffset(0) };
             while (count > 0)
             {
                 if (cursorPosition.column == ColumnOffset(0) && result.line < pageBottom)
@@ -904,12 +923,12 @@ CellLocation ViCommands::translateToCellLocation(ViMotion motion, unsigned count
                 }
                 --count;
             }
-            return result;
+            return addJumpHistory(result);
         }
         case ViMotion::ParagraphForward: // }
         {
             auto const pageBottom = _terminal->pageSize().lines.as<LineOffset>() - 1;
-            auto prev = CellLocation { cursorPosition.line, ColumnOffset(0) };
+            auto prev = CellLocation { .line = cursorPosition.line, .column = ColumnOffset(0) };
             if (prev.line < pageBottom)
                 prev.line++;
             auto current = prev;
@@ -920,7 +939,7 @@ CellLocation ViCommands::translateToCellLocation(ViMotion motion, unsigned count
                 prev.line = current.line;
                 current.line++;
             }
-            return snapToCell(current);
+            return addJumpHistory(snapToCell(current));
         }
         case ViMotion::ParenthesisMatching: // % TODO
             return findMatchingPairFrom(cursorPosition);
@@ -936,7 +955,7 @@ CellLocation ViCommands::translateToCellLocation(ViMotion motion, unsigned count
 
                 startPosition = *nextPosition;
             }
-            return startPosition;
+            return addJumpHistory(startPosition);
         }
         case ViMotion::SearchResultForward: // n
         {
@@ -949,7 +968,7 @@ CellLocation ViCommands::translateToCellLocation(ViMotion motion, unsigned count
                     return cursorPosition;
                 startPosition = *nextPosition;
             }
-            return startPosition;
+            return addJumpHistory(startPosition);
         }
         case ViMotion::WordBackward: // b
         {
@@ -1021,8 +1040,8 @@ CellLocation ViCommands::translateToCellLocation(ViMotion motion, unsigned count
         case ViMotion::WordForward: // w
         {
             auto const lastAddressableLocation =
-                CellLocation { LineOffset::cast_from(_terminal->pageSize().lines - 1),
-                               ColumnOffset::cast_from(_terminal->pageSize().columns - 1) };
+                CellLocation { .line = LineOffset::cast_from(_terminal->pageSize().lines - 1),
+                               .column = ColumnOffset::cast_from(_terminal->pageSize().columns - 1) };
             auto result = cursorPosition;
             while (count > 0)
             {
@@ -1057,12 +1076,15 @@ CellLocation ViCommands::translateToCellLocation(ViMotion motion, unsigned count
             return toCharLeft(count).value_or(cursorPosition);
         case ViMotion::RepeatCharMove:
             if (isValidCharMove(_lastCharMotion))
-                return translateToCellLocation(*_lastCharMotion, count);
+                return translateToCellLocationAndRecord(*_lastCharMotion, count);
             return cursorPosition;
         case ViMotion::RepeatCharMoveReverse:
             if (isValidCharMove(_lastCharMotion))
-                return translateToCellLocation(invertCharMove(*_lastCharMotion), count);
+                return translateToCellLocationAndRecord(invertCharMove(*_lastCharMotion), count);
             return cursorPosition;
+        case ViMotion::JumpToLastJumpPoint: return _jumpHistory.jumpToLast(cursorPosition);
+        case ViMotion::JumpToMarkBackward: return _jumpHistory.jumpToMarkBackward(cursorPosition);
+        case ViMotion::JumpToMarkForward: return _jumpHistory.jumpToMarkForward(cursorPosition);
     }
     crispy::unreachable();
 }
@@ -1131,7 +1153,7 @@ void ViCommands::moveCursor(ViMotion motion, unsigned count, char32_t lastChar)
         _lastChar = lastChar;
     }
 
-    auto const nextPosition = translateToCellLocation(motion, count);
+    auto const nextPosition = translateToCellLocationAndRecord(motion, count);
     inputLog()("Move cursor: {} to {}\n", motion, nextPosition);
     moveCursorTo(nextPosition);
 }
